Module VABufferType

Module VABufferType 

Constants

VAAlfBufferType
\brief VVC ALF data buffer
VABitPlaneBufferType
VABufferTypeMax
\brief VVC Slice Structure data buffer
VAContextParameterUpdateBufferType
\brief adjust context parameters dynamically
VADeblockingParameterBufferType
VADecodeStreamoutBufferType
decode stream out buffer, intermedia data of decode, it may include MV, MB mode etc. it can be used to detect motion and analyze the frame contain
VAEncCodedBufferType
VAEncDeltaQpPerBlockBufferType
\brief Encoding delta QP per block buffer
VAEncFEICTBCmdBufferType
\brief HEVC FEI CTB level cmd buffer it is CTB level information for future usage.
VAEncFEICURecordBufferType
\brief HEVC FEI CU level data buffer it’s CTB level information for future usage
VAEncFEIDistortionBufferType
\brief FEI specific buffer types
VAEncFEIMBCodeBufferType
\brief FEI specific buffer types
VAEncFEIMBControlBufferType
\brief FEI specific buffer types
VAEncFEIMVBufferType
\brief FEI specific buffer types
VAEncFEIMVPredictorBufferType
\brief FEI specific buffer types
VAEncMacroblockDisableSkipMapBufferType
Force MB’s to be non skip for encode.it’s per-mb control buffer, The width of the MB map Surface is (width of the Picture in MB unit) * 1 byte, multiple of 64 bytes. The height is (height of the picture in MB unit). The picture is either frame or non-interleaved top or bottom field. If the application provides this surface, it will override the “skipCheckDisable” setting in VAEncMiscParameterEncQuality.
VAEncMacroblockMapBufferType
VAEncMacroblockParameterBufferType
VAEncMiscParameterBufferType
VAEncPackedHeaderDataBufferType
VAEncPackedHeaderParameterBufferType
VAEncPictureParameterBufferType
VAEncQPBufferType
\brief Encoding QP buffer
VAEncSequenceParameterBufferType
VAEncSliceParameterBufferType
VAEncryptionParameterBufferType
\brief Encryption parameters buffer for protected content session.
VAHuffmanTableBufferType
VAIQMatrixBufferType
VAImageBufferType
VALmcsBufferType
\brief VVC LMCS data buffer
VAMacroblockParameterBufferType
VAPictureParameterBufferType
VAProbabilityBufferType
VAProcFilterParameterBufferType
\brief Video filter parameter buffer.
VAProcPipelineParameterBufferType
\brief Video processing pipeline parameter buffer.
VAProtectedSessionExecuteBufferType
\brief Protected session execution buffer type
VAProtectedSliceDataBufferType
VAQMatrixBufferType
VAResidualDataBufferType
VASliceDataBufferType
VASliceGroupMapBufferType
VASliceParameterBufferType
VASliceStructBufferType
\brief VVC Slice Structure data buffer
VAStatsMVBufferType
\brief Statistics output for VAEntrypointStats bottom field of interlaced case
VAStatsMVPredictorBufferType
\brief Statistics output for VAEntrypointStats bottom field of interlaced case
VAStatsStatisticsBottomFieldBufferType
\brief Statistics output for VAEntrypointStats bottom field of interlaced case
VAStatsStatisticsBufferType
\brief Statistics output for VAEntrypointStats progressive and top field of interlaced case
VAStatsStatisticsParameterBufferType
\brief FEI specific buffer types
VASubPicBufferType
\brief VVC SubPic data buffer
VASubsetsParameterBufferType
\brief HEVC Decoding Subset Parameter buffer type
VATileBufferType
\brief VVC Tile Dimension data buffer

Type Aliases

Type