pub type Type = c_uint;Expand description
\brief Packed header types specific to H.264 encoding.
Types of packed headers generally used for H.264 encoding. Each associated packed header data buffer shall contain the start code prefix 0x000001 followed by the complete NAL unit, thus also including the \c nal_unit_type.
Note: the start code prefix can contain an arbitrary number of leading zeros. The driver will skip them for emulation prevention bytes insertion, if necessary.