Module buffer

Module buffer 

Wrappers and helpers around VABuffers.

Structs

AV1EncLoopFilterFlags
AV1EncLoopRestorationFlags
AV1EncModeControlFlags
AV1EncPictureFlags
AV1EncQMatrixFlags
AV1EncSeqFields
AV1EncTileGroupObuHdrInfo
AV1FilmGrain
Wrapper over the film_grain_info bindgen field in VADecPictureParameterBufferAV1.
AV1FilmGrainFields
Wrapper over the film_grain_fields bindgen field in VADecPictureParameterBufferAV1.
AV1LoopFilterFields
Wrapper over the loop_filter_fields bindgen field in VADecPictureParameterBufferAV1.
AV1LoopRestorationFields
Wrapper over the loop_restoration_fields bindgen field in VADecPictureParameterBufferAV1.
AV1ModeControlFields
Wrapper over the mode_control_fields bindgen field in VADecPictureParameterBufferAV1.
AV1PicInfoFields
Wrapper over the pic_info_fields bindgen field in VADecPictureParameterBufferAV1.
AV1QMatrixFields
Wrapper over the qmatrix_fields bindgen field in VADecPictureParameterBufferAV1.
AV1SegmentInfoFields
Wrapper over the segment_info_fields bindgen field in VASegmentationStructAV1.
AV1Segmentation
Wrapper over the seg_info bindgen field in VADecPictureParameterBufferAV1.
AV1SeqFields
Wrapper over the seq_fields bindgen field in VADecPictureParameterBufferAV1.
AV1WarpedMotionParams
Wrapper over the wm bindgen field in VADecPictureParameterBufferAV1.
BlendState
Wrapper over the VABlendState ffi type.
BoolCoderContextVPX
Wrapper over the VABoolCoderContextVPX FFI type.
Buffer
Wrapper type representing a buffer created with vaCreateBuffer.
CodedBufferVP9Status
EncCodedBuffer
Wrapper type representing a buffer created with vaCreateBuffer with VAEncCodedBufferType.
EncMacroblockParameterBufferH264
EncMiscParameterBufferMaxFrameSize
EncMiscParameterBufferQualityLevel
EncMiscParameterFrameRate
EncMiscParameterHRD
EncMiscParameterMaxSliceSize
EncMiscParameterQuantization
EncMiscParameterRateControl
EncMiscParameterSkipFrame
EncPackedHeaderParameter
Abstraction over EncPackedHeaderParameterBuffer types we support
EncPictureParameterBufferAV1
EncPictureParameterBufferH264
EncPictureParameterBufferHEVC
EncPictureParameterBufferJPEG
Wrapper over the VAEncPictureParameterBufferJPEG FFI type.
EncPictureParameterBufferVP8
EncPictureParameterBufferVP9
EncSegParamAV1
EncSegParamFlagsAV1
EncSequenceParameterBufferAV1
EncSequenceParameterBufferH264
EncSequenceParameterBufferHEVC
EncSequenceParameterBufferVP8
EncSequenceParameterBufferVP9
EncSliceParameterBufferH264
EncSliceParameterBufferHEVC
EncSliceParameterBufferJPEG
Wrapper over the VAEncSliceParameterBufferJPEG FFI type.
EncSliceParameterBufferJPEGComponent
Wrapper over the components bindgen field in VAEncSliceParameterBufferJPEG.
EncTileGroupBufferAV1
EncWarpedMotionParamsAV1
H264EncFrameCropOffsets
H264EncMacroblockInfo
H264EncPicFields
H264EncSeqFields
Wrapper over the seq_fields bindgen field in VAEncSequenceParameterBufferH264
H264PicFields
Wrapper over the pic_fields bindgen field in VAPictureParameterBufferH264.
H264SeqFields
Wrapper over the seq_fields bindgen field in VAPictureParameterBufferH264.
H264VuiFields
HEVCEncPicFields
HEVCEncSeqFields
HdrMetaData
Wrapper over the VAHdrMetaData ffi type.
HevcEncPicSccFields
HevcEncSeqSccFields
HevcEncSliceFields
HevcEncVuiFields
HevcLongSliceFlags
Wrapper over the long_slice_flags bindgen field in VASliceParameterBufferHEVC.
HevcPicFields
Wrapper over the pic_fields bindgen field in VAPictureParameterBufferHEVC.
HevcRangeExtensionPicFields
Wrapper over the range_extension_pic_fields bindgen field in VAPictureParameterBufferHEVCRext.
HevcScreenContentPicFields
Wrapper over the screen_content_pic_fields bindgen field in VAPictureParameterBufferHEVCScc.
HevcSliceExtFlags
Wrapper over the slice_ext_flags bindgen field in VASliceParameterBufferHEVCRext.
HevcSliceParsingFields
Wrapper over the slice_parsing_fields bindgen field in VAPictureParameterBufferHEVC.
HuffmanTableBufferJPEGBaseline
Wrapper over the VAHuffmanTableBufferJPEGBaseline FFI type.
HuffmanTableBufferJPEGBaselineHuffmanTable
Wrapper over the huffman_table bindgen field in VAHuffmanTableBufferJPEGBaseline.
IQMatrixBufferH264
Wrapper over the VAIQMatrixBufferH264 FFI type
IQMatrixBufferHEVC
A wrapper over VAIQMatrixBufferHEVC FFI type
IQMatrixBufferJPEGBaseline
Wrapper over the VAIQMatrixBufferJPEGBaseline FFI type.
IQMatrixBufferMPEG2
Wrapper over the VAIQMatrixBufferMPEG2 FFI type.
IQMatrixBufferVP8
Wrapper over the VAIQMatrixBufferVP8 FFI type.
MPEG2PictureCodingExtension
Wrapper over the picture_coding_extension bindgen field in VAPictureParameterBufferMPEG2.
MappedCodedBuffer
Helper to access segments of mapped coded buffer
MappedCodedSegment
Helper to access a single segment of mapped coded buffer
MiscEncParamBuffer
PicFlags
Wrapper over the pic_flags bindgen field in VAEncPictureParameterBufferJPEG
PictureH264
Wrapper over the VAPictureH264 FFI type.
PictureHEVC
Wrapper over the VAPictureH264 FFI type.
PictureParameterBufferAV1
A wrapper over VADecPictureParameterBufferAV1 FFI type
PictureParameterBufferH264
A wrapper over VAPictureParameterBufferH264 FFI type
PictureParameterBufferHEVC
A wrapper over VAPictureParameterBufferHEVC FFI type
PictureParameterBufferHEVCRext
A wrapper over VAPictureParameterBufferHEVCRext FFI type
PictureParameterBufferHEVCScc
A wrapper over VAPictureParameterBufferScc FFI type
PictureParameterBufferJPEGBaseline
Wrapper over the VAPictureParameterBufferJPEGBaseline FFI type.
PictureParameterBufferJPEGBaselineComponent
Wrapper over the components bindgen field in VAPictureParameterBufferJPEGBaseline.
PictureParameterBufferMPEG2
Wrapper over the PictureParameterBufferMPEG2 FFI type.
PictureParameterBufferVP8
Wrapper over the PictureParameterBufferVP8 FFI type.
PictureParameterBufferVP9
Wrapper over the PictureParameterBufferVP9 FFI type.
ProbabilityDataBufferVP8
Wrapper over the VAProbabilityDataBufferVP8 FFI type.
ProcColorProperties
Wrapper over the VAProcColorProperties ffi type.
ProcPipelineParameterBuffer
Wrapper over the VAProcPipelineParameterBuffer FFI type.
QMatrixBufferJPEG
Wrapper over the VAQMatrixBufferJPEG FFI type.
RcFlags
RefFrameCtrlAV1
SegmentParameterVP9
Wrapper over the VASegmentParameterVP9 FFI type.
SliceParameterBufferAV1
A wrapper over an array of the VASliceParameterBufferAV1 FFI type. This allows for passing all tile parameters in a single call if multiple tiles are present in the tile group.
SliceParameterBufferH264
Wrapper over the VASliceParameterBufferH264 FFI type.
SliceParameterBufferHEVC
A wrapper over VASliceParameterBufferHEVC FFI type
SliceParameterBufferHEVCRext
A wrapper over VASliceParameterBufferHEVCRext FFI type
SliceParameterBufferJPEGBaseline
Wrapper over the VASliceParameterBufferJPEGBaseline FFI type.
SliceParameterBufferMPEG2
Wrapper over the VASliceParameterBufferMPEG2 FFI type.
SliceParameterBufferVP8
Wrapper over the VASliceParameterBufferVP8 FFI type.
SliceParameterBufferVP9
Wrapper over the VASliceParameterBufferVP9 FFI type.
VASliceParameterBufferJPEGBaselineComponent
Wrapper over the components bindgen field in VASliceParameterBufferJPEGBaseline.
VP8EncPicFlags
VP8EncRefFlags
VP8PicFields
Wrapper over the pic_fields bindgen field in VAPictureParameterBufferVP8.
VP9EncPicFlags
VP9EncRefFlags
VP9PicFields
Wrapper over the pic_fields bindgen field in VAPictureParameterBufferVP9.
VP9SegmentFlags
Wrapper over the segment_flags bindgen field in VASegmentParameterVP9.

Enums

BufferType
Abstraction over VABufferTypes.
EncMacroblockParameterBuffer
Abstraction over the EncMacroblockParameterBuffer types we support.
EncMiscParameter
Abstraction over the EncMiscParameterBuffer types we support.
EncPackedHeaderType
Abstraction over the VAEncPackedHeaderType enum values we support.
EncPictureParameter
Abstraction over the EncPictureParameter types we support.
EncSequenceParameter
Abstraction over the EncSequenceParameter types we support.
EncSliceParameter
Abstraction over the EncSliceParameter types we support.
HuffmanTable
Abstraction over the HuffmanTable types we support.
IQMatrix
Abstraction over the IQMatrixBuffer types we support.
PictureParameter
Abstraction over the PictureParameterBuffer types we support.
QMatrix
Abstraction over the QMatrix types we support.
SliceParameter
Abstraction over the SliceParameterBuffer types we support