pub struct SliceParameterBufferHEVC(/* private fields */);Expand description
A wrapper over VASliceParameterBufferHEVC FFI type
Implementations
Sourceimpl SliceParameterBufferHEVC
impl SliceParameterBufferHEVC
Sourcepub fn new(
slice_data_size: u32,
slice_data_offset: u32,
slice_data_flag: u32,
slice_data_byte_offset: u32,
slice_segment_address: u32,
ref_pic_list: [[u8; 15]; 2],
long_slice_flags: &HevcLongSliceFlags,
collocated_ref_idx: u8,
num_ref_idx_l0_active_minus1: u8,
num_ref_idx_l1_active_minus1: u8,
slice_qp_delta: i8,
slice_cb_qp_offset: i8,
slice_cr_qp_offset: i8,
slice_beta_offset_div2: i8,
slice_tc_offset_div2: i8,
luma_log2_weight_denom: u8,
delta_chroma_log2_weight_denom: i8,
delta_luma_weight_l0: [i8; 15],
luma_offset_l0: [i8; 15],
delta_chroma_weight_l0: [[i8; 2]; 15],
chroma_offset_l0: [[i8; 2]; 15],
delta_luma_weight_l1: [i8; 15],
luma_offset_l1: [i8; 15],
delta_chroma_weight_l1: [[i8; 2]; 15],
chroma_offset_l1: [[i8; 2]; 15],
five_minus_max_num_merge_cand: u8,
num_entry_point_offsets: u16,
entry_offset_to_subset_array: u16,
slice_data_num_emu_prevn_bytes: u16,
) -> Self
pub fn new( slice_data_size: u32, slice_data_offset: u32, slice_data_flag: u32, slice_data_byte_offset: u32, slice_segment_address: u32, ref_pic_list: [[u8; 15]; 2], long_slice_flags: &HevcLongSliceFlags, collocated_ref_idx: u8, num_ref_idx_l0_active_minus1: u8, num_ref_idx_l1_active_minus1: u8, slice_qp_delta: i8, slice_cb_qp_offset: i8, slice_cr_qp_offset: i8, slice_beta_offset_div2: i8, slice_tc_offset_div2: i8, luma_log2_weight_denom: u8, delta_chroma_log2_weight_denom: i8, delta_luma_weight_l0: [i8; 15], luma_offset_l0: [i8; 15], delta_chroma_weight_l0: [[i8; 2]; 15], chroma_offset_l0: [[i8; 2]; 15], delta_luma_weight_l1: [i8; 15], luma_offset_l1: [i8; 15], delta_chroma_weight_l1: [[i8; 2]; 15], chroma_offset_l1: [[i8; 2]; 15], five_minus_max_num_merge_cand: u8, num_entry_point_offsets: u16, entry_offset_to_subset_array: u16, slice_data_num_emu_prevn_bytes: u16, ) -> Self
Creates the wrapper
Sourcepub fn set_as_last(&mut self)
pub fn set_as_last(&mut self)
Set this slice as the last one after creation. Implementations may only be able to conveniently see if this is the last slice after it has been created.
Sourcepub fn inner(&self) -> &VASliceParameterBufferHEVC
pub fn inner(&self) -> &VASliceParameterBufferHEVC
Returns the inner FFI type. Useful for testing purposes.