RefPicMarkingInner

Struct RefPicMarkingInner 

pub struct RefPicMarkingInner {
    pub memory_management_control_operation: u8,
    pub difference_of_pic_nums_minus1: u32,
    pub long_term_pic_num: u32,
    pub long_term_frame_idx: u32,
    pub max_long_term_frame_idx: MaxLongTermFrameIdx,
}

Fields

memory_management_control_operation: u8

Specifies a control operation to be applied to affect the reference picture marking. The memory_management_control_operation syntax element is followed by data necessary for the operation specified by the value of memory_management_control_operation. The values and control operations associated with memory_management_control_operation are specified in Table 7-9

difference_of_pic_nums_minus1: u32

Used (with memory_management_control_operation equal to 3 or 1) to assign a long-term frame index to a short-term reference picture or to mark a short-term reference picture as “unused for reference”.

long_term_pic_num: u32

Used (with memory_management_control_operation equal to 2) to mark a long-term reference picture as “unused for reference”.

long_term_frame_idx: u32

Used (with memory_management_control_operation equal to 3 or 6) to assign a long-term frame index to a picture.

max_long_term_frame_idx: MaxLongTermFrameIdx

Specifies the maximum value of long-term frame index allowed for long-term reference pictures (until receipt of another value of max_long_term_frame_idx_plus1).