vaBufferSetNumElements

Function vaBufferSetNumElements 

pub unsafe extern "C" fn vaBufferSetNumElements(
    dpy: VADisplay,
    buf_id: VABufferID,
    num_elements: c_uint,
) -> VAStatus
Convey to the server how many valid elements are in the buffer. e.g. if multiple slice parameters are being held in a single buffer, this will communicate to the server the number of slice parameters that are valid in the buffer.