pub unsafe extern "C" fn vaCreateBuffer(
dpy: VADisplay,
context: VAContextID,
type_: Type,
size: c_uint,
num_elements: c_uint,
data: *mut c_void,
buf_id: *mut VABufferID,
) -> VAStatusExpand description
Creates a buffer for “num_elements” elements of “size” bytes and initalize with “data”. if “data” is null, then the contents of the buffer data store are undefined. Basically there are two ways to get buffer data to the server side. One is to call vaCreateBuffer() with a non-null “data”, which results the data being copied to the data store on the server side. A different method that eliminates this copy is to pass null as “data” when calling vaCreateBuffer(), and then use vaMapBuffer() to map the data store from the server side to the client address space for access. The user must call vaDestroyBuffer() to destroy a buffer. Note: image buffers are created by the library, not the client. Please see vaCreateImage on how image buffers are managed.