vaCreateConfig

Function vaCreateConfig 

pub unsafe extern "C" fn vaCreateConfig(
    dpy: VADisplay,
    profile: Type,
    entrypoint: Type,
    attrib_list: *mut VAConfigAttrib,
    num_attribs: c_int,
    config_id: *mut VAConfigID,
) -> VAStatus
Create a configuration for the video decode/encode/processing pipeline it passes in the attribute list that specifies the attributes it cares about, with the rest taking default values.