vaDestroyBuffer

Function vaDestroyBuffer 

pub unsafe extern "C" fn vaDestroyBuffer(
    dpy: VADisplay,
    buffer_id: VABufferID,
) -> VAStatus
After this call, the buffer is deleted and this buffer_id is no longer valid

A buffer can be re-used and sent to the server by another Begin/Render/End sequence if vaDestroyBuffer() is not called with this buffer.

Note re-using a shared buffer (e.g. a slice data buffer) between the host and the hardware accelerator can result in performance dropping.