vaDestroySurfaces

Function vaDestroySurfaces 

pub unsafe extern "C" fn vaDestroySurfaces(
    dpy: VADisplay,
    surfaces: *mut VASurfaceID,
    num_surfaces: c_int,
) -> VAStatus
vaDestroySurfaces - Destroy resources associated with surfaces. Surfaces can only be destroyed after all contexts using these surfaces have been destroyed. dpy: display surfaces: array of surfaces to destroy num_surfaces: number of surfaces in the array to be destroyed.