vaDetachProtectedSession

Function vaDetachProtectedSession 

pub unsafe extern "C" fn vaDetachProtectedSession(
    dpy: VADisplay,
    id: VAGenericID,
) -> VAStatus
\brief Detach the protected content session from the VA context

Detach protected content session of the context to disable decryption/protection

@param[in] dpy the VA display @param[in] id TEE client id to be detached