vaGetConfigAttributes

Function vaGetConfigAttributes 

pub unsafe extern "C" fn vaGetConfigAttributes(
    dpy: VADisplay,
    profile: Type,
    entrypoint: Type,
    attrib_list: *mut VAConfigAttrib,
    num_attribs: c_int,
) -> VAStatus
Get attributes for a given profile/entrypoint pair The caller must provide an “attrib_list” with all attributes to be retrieved. Upon return, the attributes in “attrib_list” have been updated with their value. Unknown attributes or attributes that are not supported for the given profile/entrypoint pair will have their value set to VA_ATTRIB_NOT_SUPPORTED