pub unsafe extern "C" fn vaGetLibFunc(
dpy: VADisplay,
func: *const c_char,
) -> VAPrivFuncExpand description
Return a function pointer given a function name in the library. This allows private interfaces into the library
pub unsafe extern "C" fn vaGetLibFunc(
dpy: VADisplay,
func: *const c_char,
) -> VAPrivFuncReturn a function pointer given a function name in the library. This allows private interfaces into the library