vaQueryConfigAttributes

Function vaQueryConfigAttributes 

pub unsafe extern "C" fn vaQueryConfigAttributes(
    dpy: VADisplay,
    config_id: VAConfigID,
    profile: *mut Type,
    entrypoint: *mut Type,
    attrib_list: *mut VAConfigAttrib,
    num_attribs: *mut c_int,
) -> VAStatus
Query all attributes for a given configuration The profile of the configuration is returned in “profile” The entrypoint of the configuration is returned in “entrypoint” The caller must provide an “attrib_list” array that can hold at least vaMaxNumConfigAttributes() entries. The actual number of attributes returned in “attrib_list” is returned in “num_attribs”