vaQueryProcessingRate

Function vaQueryProcessingRate 

pub unsafe extern "C" fn vaQueryProcessingRate(
    dpy: VADisplay,
    config: VAConfigID,
    proc_buf: *mut VAProcessingRateParameter,
    processing_rate: *mut c_uint,
) -> VAStatus
\brief Queries processing rate for the supplied config.

This function queries the processing rate based on parameters in \c proc_buf for the given \c config. Upon successful return, the processing rate value will be stored in \c processing_rate. Processing rate is specified as the number of macroblocks/CTU per second.

If NULL is passed to the \c proc_buf, the default processing rate for the given configuration will be returned.

@param[in] dpy the VA display @param[in] config the config identifying a codec or a video processing pipeline @param[in] proc_buf the buffer that contains the parameters for either the encode or decode processing rate @param[out] processing_rate processing rate in number of macroblocks per second constrained by parameters specified in proc_buf