vaQuerySurfaceAttributes

Function vaQuerySurfaceAttributes 

pub unsafe extern "C" fn vaQuerySurfaceAttributes(
    dpy: VADisplay,
    config: VAConfigID,
    attrib_list: *mut VASurfaceAttrib,
    num_attribs: *mut c_uint,
) -> VAStatus
\brief Queries surface attributes for the supplied config.

This function queries for all supported attributes for the supplied VA \c config. In particular, if the underlying hardware supports the creation of VA surfaces in various formats, then this function will enumerate all pixel formats that are supported.

The \c attrib_list array is allocated by the user and \c num_attribs shall be initialized to the number of allocated elements in that array. Upon successful return, the actual number of attributes will be overwritten into \c num_attribs. Otherwise, \c VA_STATUS_ERROR_MAX_NUM_EXCEEDED is returned and \c num_attribs is adjusted to the number of elements that would be returned if enough space was available.

Note: it is perfectly valid to pass NULL to the \c attrib_list argument when vaQuerySurfaceAttributes() is used to determine the actual number of elements that need to be allocated.

@param[in] dpy the VA display @param[in] config the config identifying a codec or a video processing pipeline @param[out] attrib_list the output array of #VASurfaceAttrib elements @param[in,out] num_attribs the number of elements allocated on input, the number of elements actually filled in output