vaQueryVideoProcFilterCaps

Function vaQueryVideoProcFilterCaps 

pub unsafe extern "C" fn vaQueryVideoProcFilterCaps(
    dpy: VADisplay,
    context: VAContextID,
    type_: VAProcFilterType,
    filter_caps: *mut c_void,
    num_filter_caps: *mut c_uint,
) -> VAStatus
\brief Queries video filter capabilities.

This function returns the list of capabilities supported by the driver for a specific video filter. The \c filter_caps array is allocated by the user and \c num_filter_caps shall be initialized to the number of allocated elements in that array. Upon successful return, the actual number of filters will be overwritten into \c num_filter_caps. Otherwise, \c VA_STATUS_ERROR_MAX_NUM_EXCEEDED is returned and \c num_filter_caps is adjusted to the number of elements that would be returned if enough space was available.

@param[in] dpy the VA display @param[in] context the video processing context @param[in] type the video filter type @param[out] filter_caps the output array of #VAProcFilterCap elements @param[in,out] num_filter_caps the number of elements allocated on input, the number of elements actually filled in output