pub unsafe extern "C" fn vaQueryVideoProcFilters(
dpy: VADisplay,
context: VAContextID,
filters: *mut VAProcFilterType,
num_filters: *mut c_uint,
) -> VAStatusExpand description
\brief Queries video processing filters.
This function returns the list of video processing filters supported by the driver. The \c filters array is allocated by the user and \c num_filters shall be initialized to the number of allocated elements in that array. Upon successful return, the actual number of filters will be overwritten into \c num_filters. Otherwise, \c VA_STATUS_ERROR_MAX_NUM_EXCEEDED is returned and \c num_filters is adjusted to the number of elements that would be returned if enough space was available.
The list of video processing filters supported by the driver shall be ordered in the way they can be iteratively applied. This is needed for both correctness, i.e. some filters would not mean anything if applied at the beginning of the pipeline; but also for performance since some filters can be applied in a single pass (e.g. noise reduction + deinterlacing).
@param[in] dpy the VA display @param[in] context the video processing context @param[out] filters the output array of #VAProcFilterType elements @param[in,out] num_filters the number of elements allocated on input, the number of elements actually filled in on output