vaQueryVideoProcPipelineCaps

Function vaQueryVideoProcPipelineCaps 

pub unsafe extern "C" fn vaQueryVideoProcPipelineCaps(
    dpy: VADisplay,
    context: VAContextID,
    filters: *mut VABufferID,
    num_filters: c_uint,
    pipeline_caps: *mut VAProcPipelineCaps,
) -> VAStatus
\brief Queries video processing pipeline capabilities.

This function returns the video processing pipeline capabilities. The \c filters array defines the video processing pipeline and is an array of buffers holding filter parameters.

Note: the #VAProcPipelineCaps structure contains user-provided arrays. If non-NULL, the corresponding \c num_* fields shall be filled in on input with the number of elements allocated. Upon successful return, the actual number of elements will be overwritten into the \c num_* fields. Otherwise, \c VA_STATUS_ERROR_MAX_NUM_EXCEEDED is returned and \c num_* fields are adjusted to the number of elements that would be returned if enough space was available.

@param[in] dpy the VA display @param[in] context the video processing context @param[in] filters the array of VA buffers defining the video processing pipeline @param[in] num_filters the number of elements in filters @param[in,out] pipeline_caps the video processing pipeline capabilities