pub unsafe extern "C" fn vaRenderPicture(
dpy: VADisplay,
context: VAContextID,
buffers: *mut VABufferID,
num_buffers: c_int,
) -> VAStatusExpand description
Send video decode, encode or processing buffers to the server.
pub unsafe extern "C" fn vaRenderPicture(
dpy: VADisplay,
context: VAContextID,
buffers: *mut VABufferID,
num_buffers: c_int,
) -> VAStatusSend video decode, encode or processing buffers to the server.