vaSetDisplayAttributes

Function vaSetDisplayAttributes 

pub unsafe extern "C" fn vaSetDisplayAttributes(
    dpy: VADisplay,
    attr_list: *mut VADisplayAttribute,
    num_attributes: c_int,
) -> VAStatus
Set display attributes Only attributes returned with VA_DISPLAY_ATTRIB_SETTABLE set in the “flags” field from vaQueryDisplayAttributes() can be set. If the attribute is not settable or the value is out of range, the function returns VA_STATUS_ERROR_ATTR_NOT_SUPPORTED