pub unsafe extern "C" fn vaSyncBuffer(
dpy: VADisplay,
buf_id: VABufferID,
timeout_ns: u64,
) -> VAStatusExpand description
\brief Synchronizes pending operations associated with the supplied buffer.
This function blocks during specified timeout (in nanoseconds) until all pending operations on the supplied buffer have been completed. If timeout is zero, the function returns immediately.
Possible errors:
- \ref VA_STATUS_ERROR_UNIMPLEMENTED: the VA driver implementation does not support this interface
- \ref VA_STATUS_ERROR_INVALID_DISPLAY: an invalid display was supplied
- \ref VA_STATUS_ERROR_INVALID_BUFFER: an invalid buffer was supplied
- \ref VA_STATUS_ERROR_TIMEDOUT: synchronization is still in progress, client should call the function again to complete synchronization
@param[in] dpy the VA display @param[in] buf_id the buffer for which synchronization is performed @param[in] timeout_ns the timeout in nanoseconds