vaUnmapBuffer

Function vaUnmapBuffer 

pub unsafe extern "C" fn vaUnmapBuffer(
    dpy: VADisplay,
    buf_id: VABufferID,
) -> VAStatus
After client making changes to a mapped data store, it needs to “Unmap” it to let the server know that the data is ready to be consumed by the server