pub struct Surface<D: SurfaceMemoryDescriptor> { /* private fields */ }Expand description
An owned VA surface that is tied to a particular Display.
Implementations
Sourceimpl<D: SurfaceMemoryDescriptor> Surface<D>
impl<D: SurfaceMemoryDescriptor> Surface<D>
pub fn display(&self) -> &Arc<Display>
Sourcepub fn sync(&self) -> Result<(), VaError>
pub fn sync(&self) -> Result<(), VaError>
Wrapper around vaSyncSurface that blocks until all pending operations on the render
target have been completed.
Upon return it is safe to use the render target for a different picture.
Sourcepub fn as_id_vec(surfaces: &[Self]) -> Vec<VASurfaceID> ⓘ
pub fn as_id_vec(surfaces: &[Self]) -> Vec<VASurfaceID> ⓘ
Convenience function to return a VASurfaceID vector. Useful to interface with the C API where a surface array might be needed.
Sourcepub fn query_status(&self) -> Result<Type, VaError>
pub fn query_status(&self) -> Result<Type, VaError>
Wrapper over vaQuerySurfaceStatus to find out any pending ops on the render target.
pub fn query_error(&self) -> Result<Vec<SurfaceDecodeMBError>, VaError>
Sourcepub fn id(&self) -> VASurfaceID
pub fn id(&self) -> VASurfaceID
Returns the ID of this surface.
Sourcepub fn export_prime(&self) -> Result<DrmPrimeSurfaceDescriptor, VaError>
pub fn export_prime(&self) -> Result<DrmPrimeSurfaceDescriptor, VaError>
Returns a PRIME descriptor for this surface.