#[repr(C)]pub struct VABufferInfo {
pub handle: usize,
pub type_: u32,
pub mem_type: u32,
pub mem_size: usize,
pub va_reserved: [u32; 4],
}Expand description
\brief VA buffer information
Fields
handle: usize\brief Buffer handle
type_: u32\brief Buffer type (See \ref VABufferType).
mem_type: u32\brief Buffer memory type (See \ref VASurfaceAttribMemoryType).
On input to vaAcquireBufferHandle(), this field can serve as a hint to specify the set of memory types the caller is interested in. On successful return from vaAcquireBufferHandle(), the field is updated with the best matching memory type.
mem_size: usize\brief Size of the underlying buffer.
va_reserved: [u32; 4]\brief Reserved bytes for future use, must be zero