#[repr(C)]pub struct _VABlendState {
pub flags: c_uint,
pub global_alpha: f32,
pub min_luma: f32,
pub max_luma: f32,
}Expand description
\brief Video blending state definition.
Fields
flags: c_uint\brief Video blending flags.
global_alpha: f32\brief Global alpha value.
Valid if \ref flags has VA_BLEND_GLOBAL_ALPHA. Valid range is 0.0 to 1.0 inclusive.
min_luma: f32\brief Minimum luma value.
Valid if \ref flags has VA_BLEND_LUMA_KEY. Valid range is 0.0 to 1.0 inclusive. \ref min_luma shall be set to a sensible value lower than \ref max_luma.
max_luma: f32\brief Maximum luma value.
Valid if \ref flags has VA_BLEND_LUMA_KEY. Valid range is 0.0 to 1.0 inclusive. \ref max_luma shall be set to a sensible value larger than \ref min_luma.