_VAEncFEIMBCodeH264

Struct _VAEncFEIMBCodeH264 

#[repr(C)]
pub struct _VAEncFEIMBCodeH264 { pub reserved0: [u32; 3], pub _bitfield_align_1: [u32; 0], pub _bitfield_1: __BindgenBitfieldUnit<[u8; 16]>, pub mb_mode: _VAEncFEIMBCodeH264__bindgen_ty_1, pub _bitfield_align_2: [u16; 0], pub _bitfield_2: __BindgenBitfieldUnit<[u8; 4]>, pub reserved9: [u32; 4], pub reserved10: u32, }
\brief VAEncFEIMBCodeH264 defines the data structure for VAEncFEIMBCodeBufferType per 16x16 MB block. it is output buffer of ENC and ENC_PAK modes, it’s also input buffer of PAK mode. The 16x16 block is in raster scan order. Buffer size shall not be less than the number of 16x16 blocks multiplied by sizeof(VAEncFEIMBCodeH264). Note that, when separate ENC and PAK is enabled, the exact layout of this buffer is needed for PAK input. App can reuse this buffer, or copy to a different buffer as PAK input, reserved elements must not be modified when used as PAK input.

Fields

reserved0: [u32; 3]_bitfield_align_1: [u32; 0]_bitfield_1: __BindgenBitfieldUnit<[u8; 16]>mb_mode: _VAEncFEIMBCodeH264__bindgen_ty_1_bitfield_align_2: [u16; 0]_bitfield_2: __BindgenBitfieldUnit<[u8; 4]>reserved9: [u32; 4]reserved10: u32

Implementations

Source

impl _VAEncFEIMBCodeH264

pub fn inter_mb_mode(&self) -> u32

pub fn set_inter_mb_mode(&mut self, val: u32)

pub fn mb_skip_flag(&self) -> u32

pub fn set_mb_skip_flag(&mut self, val: u32)

pub fn reserved1(&self) -> u32

pub fn set_reserved1(&mut self, val: u32)

pub fn intra_mb_mode(&self) -> u32

pub fn set_intra_mb_mode(&mut self, val: u32)

pub fn reserved2(&self) -> u32

pub fn set_reserved2(&mut self, val: u32)

pub fn field_mb_polarity_flag(&self) -> u32

pub fn set_field_mb_polarity_flag(&mut self, val: u32)

pub fn mb_type(&self) -> u32

pub fn set_mb_type(&mut self, val: u32)

pub fn intra_mb_flag(&self) -> u32

pub fn set_intra_mb_flag(&mut self, val: u32)

pub fn field_mb_flag(&self) -> u32

pub fn set_field_mb_flag(&mut self, val: u32)

pub fn transform8x8_flag(&self) -> u32

pub fn set_transform8x8_flag(&mut self, val: u32)

pub fn reserved3(&self) -> u32

pub fn set_reserved3(&mut self, val: u32)

pub fn dc_block_coded_cr_flag(&self) -> u32

pub fn set_dc_block_coded_cr_flag(&mut self, val: u32)

pub fn dc_block_coded_cb_flag(&self) -> u32

pub fn set_dc_block_coded_cb_flag(&mut self, val: u32)

pub fn dc_block_coded_y_flag(&self) -> u32

pub fn set_dc_block_coded_y_flag(&mut self, val: u32)

pub fn reserved4(&self) -> u32

pub fn set_reserved4(&mut self, val: u32)

pub fn horz_origin(&self) -> u32

pub fn set_horz_origin(&mut self, val: u32)

pub fn vert_origin(&self) -> u32

pub fn set_vert_origin(&mut self, val: u32)

pub fn cbp_y(&self) -> u32

pub fn set_cbp_y(&mut self, val: u32)

pub fn cbp_cb(&self) -> u32

pub fn set_cbp_cb(&mut self, val: u32)

pub fn cbp_cr(&self) -> u32

pub fn set_cbp_cr(&mut self, val: u32)

pub fn qp_prime_y(&self) -> u32

pub fn set_qp_prime_y(&mut self, val: u32)

pub fn reserved5(&self) -> u32

pub fn set_reserved5(&mut self, val: u32)

pub fn mb_skip_conv_disable(&self) -> u32

pub fn set_mb_skip_conv_disable(&mut self, val: u32)

pub fn is_last_mb(&self) -> u32

pub fn set_is_last_mb(&mut self, val: u32)

pub fn enable_coefficient_clamp(&self) -> u32

pub fn set_enable_coefficient_clamp(&mut self, val: u32)

pub fn direct8x8_pattern(&self) -> u32

pub fn set_direct8x8_pattern(&mut self, val: u32)

pub fn new_bitfield_1( inter_mb_mode: u32, mb_skip_flag: u32, reserved1: u32, intra_mb_mode: u32, reserved2: u32, field_mb_polarity_flag: u32, mb_type: u32, intra_mb_flag: u32, field_mb_flag: u32, transform8x8_flag: u32, reserved3: u32, dc_block_coded_cr_flag: u32, dc_block_coded_cb_flag: u32, dc_block_coded_y_flag: u32, reserved4: u32, horz_origin: u32, vert_origin: u32, cbp_y: u32, cbp_cb: u32, cbp_cr: u32, qp_prime_y: u32, reserved5: u32, mb_skip_conv_disable: u32, is_last_mb: u32, enable_coefficient_clamp: u32, direct8x8_pattern: u32, ) -> __BindgenBitfieldUnit<[u8; 16]>

pub fn reserved8(&self) -> u32

pub fn set_reserved8(&mut self, val: u32)

pub fn target_size_in_word(&self) -> u32

pub fn set_target_size_in_word(&mut self, val: u32)

pub fn max_size_in_word(&self) -> u32

pub fn set_max_size_in_word(&mut self, val: u32)

pub fn new_bitfield_2( reserved8: u32, target_size_in_word: u32, max_size_in_word: u32, ) -> __BindgenBitfieldUnit<[u8; 4]>