_VAEncMBMapBufferVP8

Struct _VAEncMBMapBufferVP8 

#[repr(C)]
pub struct _VAEncMBMapBufferVP8 { pub num_mbs: u32, pub mb_segment_id: *mut u8, pub va_reserved: [u32; 4], }
\brief VP8 MB Segmentation ID Buffer

application provides buffer containing the initial segmentation id for each MB, in raster scan order. Rate control may reassign it. For an 640x480 video, the buffer has 1200 entries. the value of each entry should be in the range [0..3], inclusive. If segmentation is not enabled, application does not need to provide it.

Fields

num_mbs: u32

number of MBs in the frame. It is also the number of entries of mb_segment_id[];

mb_segment_id: *mut u8

per MB Segmentation ID Buffer

va_reserved: [u32; 4]

\brief Reserved bytes for future use, must be zero