_VAEncMiscParameterBufferMaxFrameSize

Struct _VAEncMiscParameterBufferMaxFrameSize 

#[repr(C)]
pub struct _VAEncMiscParameterBufferMaxFrameSize { pub type_: Type, pub max_frame_size: u32, pub va_reserved: [u32; 4], }
\brief Defines a maximum frame size (in bits).

This misc parameter buffer defines the maximum size of a frame (in bits). The encoder will try to make sure that each frame does not exceed this size. Otherwise, if the frame size exceeds this size, the \c status flag of #VACodedBufferSegment will contain #VA_CODED_BUF_STATUS_FRAME_SIZE_OVERFLOW.

Fields

type_: Type

\brief Type. Shall be set to #VAEncMiscParameterTypeMaxFrameSize. / /* duplicated with VAEncMiscParameterBuffer, should be deprecated

max_frame_size: u32

\brief Maximum size of a frame (in bits).

va_reserved: [u32; 4]

\brief Reserved bytes for future use, must be zero