_VAEncMiscParameterBufferMultiPassFrameSize

Struct _VAEncMiscParameterBufferMultiPassFrameSize 

#[repr(C)]
pub struct _VAEncMiscParameterBufferMultiPassFrameSize { pub type_: Type, pub max_frame_size: u32, pub reserved: u32, pub num_passes: u8, pub delta_qp: *mut u8, pub va_reserved: [c_ulong; 4], }
\brief Maximum frame size (in bytes) settings for multiple pass.

This misc parameter buffer defines the maximum size of a frame (in bytes) settings for multiple pass. currently only AVC encoder can support this settings in multiple pass case. If the frame size exceeds this size, the encoder will do more pak passes to adjust the QP value to control the frame size.

Fields

type_: Type

\brief Type. Shall be set to #VAEncMiscParameterTypeMultiPassMaxFrameSize. / /* duplicated with VAEncMiscParameterBuffer, should be deprecated

max_frame_size: u32

\brief Maximum size of a frame (in byte)

reserved: u32

\brief Reserved bytes for future use, must be zero

num_passes: u8

\brief number of passes, every pass has different QP, currently AVC encoder can support up to 4 passes

delta_qp: *mut u8

\brief delta QP list for every pass

va_reserved: [c_ulong; 4]

\brief Reserved bytes for future use, must be zero