_VAEncMiscParameterBufferQualityLevel

Struct _VAEncMiscParameterBufferQualityLevel 

#[repr(C)]
pub struct _VAEncMiscParameterBufferQualityLevel { pub quality_level: u32, pub va_reserved: [u32; 4], }
\brief Encoding quality level.

The encoding quality could be set through this structure, if the implementation supports multiple quality levels. The quality level set through this structure is persistent over the entire coded sequence, or until a new structure is being sent. The quality level range can be queried through the VAConfigAttribEncQualityRange attribute. A lower value means higher quality, and a value of 1 represents the highest quality. The quality level setting is used as a trade-off between quality and speed/power consumption, with higher quality corresponds to lower speed and higher power consumption.

Fields

quality_level: u32

\brief Encoding quality level setting. When set to 0, default quality level is used.

va_reserved: [u32; 4]

\brief Reserved bytes for future use, must be zero