#[repr(C)]pub struct _VAEncMiscParameterEncQuality {
pub __bindgen_anon_1: _VAEncMiscParameterEncQuality__bindgen_ty_1,
pub FTQSkipThresholdLUT: [u8; 52],
pub NonFTQSkipThresholdLUT: [u16; 52],
pub reserved: [u32; 16],
}Expand description
per frame encoder quality controls, once set they will persist for all future frames till it is updated again.
Fields
__bindgen_anon_1: _VAEncMiscParameterEncQuality__bindgen_ty_1FTQSkipThresholdLUT: [u8; 52]Maps QP to skip thresholds when FTQ is enabled. Valid range is 0-255.
NonFTQSkipThresholdLUT: [u16; 52]Maps QP to skip thresholds when FTQ is disabled. Valid range is 0-65535.
reserved: [u32; 16]Trait Implementations
Sourceimpl Clone for _VAEncMiscParameterEncQuality
impl Clone for _VAEncMiscParameterEncQuality
Sourcefn clone(&self) -> _VAEncMiscParameterEncQuality
fn clone(&self) -> _VAEncMiscParameterEncQuality
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for _VAEncMiscParameterEncQuality