_VAEncMiscParameterFEIFrameControlHEVC

Struct _VAEncMiscParameterFEIFrameControlHEVC 

#[repr(C)]
pub struct _VAEncMiscParameterFEIFrameControlHEVC {
Show 13 fields pub function: u32, pub ctb_ctrl: VABufferID, pub ctb_cmd: VABufferID, pub cu_record: VABufferID, pub distortion: VABufferID, pub qp: VABufferID, pub mv_predictor: VABufferID, pub _bitfield_align_1: [u32; 0], pub _bitfield_1: __BindgenBitfieldUnit<[u8; 20]>, pub max_frame_size: u32, pub num_passes: u32, pub delta_qp: *mut u8, pub reserved4: [u32; 2],
}
\brief FEI frame level control buffer for HEVC

Fields

function: u32ctb_ctrl: VABufferID

\brief CTB control input buffer. It is valid only when per_ctb_input is set to 1. The data in this buffer correspond to the input source. CTB is in raster scan order, each CTB control data structure is defined by VAEncFEICTBControlHEVC. Buffer size shall not be less than the number of CTBs multiplied by sizeof(VAEncFEICTBControlHEVC).

ctb_cmd: VABufferID

\brief CTB cmd per CTB data output of ENC it is reserved for CTB level information it should include CU split information and other CTB datas . Each CTB block has one CTB cmd data.

cu_record: VABufferID

\brief CU record data output of ENC it is reserved for CU level information it should include CU detail data. include mode,MV, reference etc. Each CTB block has one CU record data.

distortion: VABufferID

\brief distortion output of ENC or ENC_PAK. Each CTB has one distortion data with VAEncFEIDistortionHevc Buffer size shall not be less than the number of CTBs multiplied by sizeof(VAEncFEIDistortionHevc).

qp: VABufferID

\brief Qp input buffer. It is valid only when per_block_qp is set to 1. The data in this buffer correspond to the input source. One Qp per block block is in raster scan order, each Qp is a signed char (8-bit) value.

mv_predictor: VABufferID

\brief MV predictor. It is valid only when mv_predictor_input is set to non-zero. Each CTB block has one or more pair of motion vectors and the corresponding reference indexes as defined by VAEncFEIMVPredictorHEVC. 32x32 block is in raster scan order. Buffer size shall not be less than the number of 16x16 blocks multiplied by sizeof(VAEncFEIMVPredictorHEVC).

_bitfield_align_1: [u32; 0]_bitfield_1: __BindgenBitfieldUnit<[u8; 20]>max_frame_size: u32

\brief max frame size control with multi passes QP setting

num_passes: u32

\brief number of passes, every pass has different QP

delta_qp: *mut u8

\brief delta QP list for every pass

reserved4: [u32; 2]

Implementations

Source

impl _VAEncMiscParameterFEIFrameControlHEVC

pub fn num_mv_predictors_l0(&self) -> u32

pub fn set_num_mv_predictors_l0(&mut self, val: u32)

pub fn num_mv_predictors_l1(&self) -> u32

pub fn set_num_mv_predictors_l1(&mut self, val: u32)

pub fn search_path(&self) -> u32

pub fn set_search_path(&mut self, val: u32)

pub fn len_sp(&self) -> u32

pub fn set_len_sp(&mut self, val: u32)

pub fn reserved0(&self) -> u32

pub fn set_reserved0(&mut self, val: u32)

pub fn multi_pred_l0(&self) -> u32

pub fn set_multi_pred_l0(&mut self, val: u32)

pub fn multi_pred_l1(&self) -> u32

pub fn set_multi_pred_l1(&mut self, val: u32)

pub fn sub_pel_mode(&self) -> u32

pub fn set_sub_pel_mode(&mut self, val: u32)

pub fn mv_predictor_input(&self) -> u32

pub fn set_mv_predictor_input(&mut self, val: u32)

pub fn per_block_qp(&self) -> u32

pub fn set_per_block_qp(&mut self, val: u32)

pub fn per_ctb_input(&self) -> u32

pub fn set_per_ctb_input(&mut self, val: u32)

pub fn colocated_ctb_distortion(&self) -> u32

pub fn set_colocated_ctb_distortion(&mut self, val: u32)

pub fn force_lcu_split(&self) -> u32

pub fn set_force_lcu_split(&mut self, val: u32)

pub fn enable_cu64_check(&self) -> u32

pub fn set_enable_cu64_check(&mut self, val: u32)

pub fn enable_cu64_amp_check(&self) -> u32

pub fn set_enable_cu64_amp_check(&mut self, val: u32)

pub fn cu64_skip_check_only(&self) -> u32

pub fn set_cu64_skip_check_only(&mut self, val: u32)

pub fn reserved1(&self) -> u32

pub fn set_reserved1(&mut self, val: u32)

pub fn ref_width(&self) -> u32

pub fn set_ref_width(&mut self, val: u32)

pub fn ref_height(&self) -> u32

pub fn set_ref_height(&mut self, val: u32)

pub fn search_window(&self) -> u32

pub fn set_search_window(&mut self, val: u32)

pub fn max_num_ime_search_center(&self) -> u32

pub fn set_max_num_ime_search_center(&mut self, val: u32)

pub fn fast_intra_mode(&self) -> u32

pub fn set_fast_intra_mode(&mut self, val: u32)

pub fn reserved2(&self) -> u32

pub fn set_reserved2(&mut self, val: u32)

pub fn num_concurrent_enc_frame_partition(&self) -> u32

pub fn set_num_concurrent_enc_frame_partition(&mut self, val: u32)

pub fn reserved3(&self) -> u32

pub fn set_reserved3(&mut self, val: u32)

pub fn new_bitfield_1( num_mv_predictors_l0: u32, num_mv_predictors_l1: u32, search_path: u32, len_sp: u32, reserved0: u32, multi_pred_l0: u32, multi_pred_l1: u32, sub_pel_mode: u32, adaptive_search: u32, mv_predictor_input: u32, per_block_qp: u32, per_ctb_input: u32, colocated_ctb_distortion: u32, force_lcu_split: u32, enable_cu64_check: u32, enable_cu64_amp_check: u32, cu64_skip_check_only: u32, reserved1: u32, ref_width: u32, ref_height: u32, search_window: u32, max_num_ime_search_center: u32, fast_intra_mode: u32, reserved2: u32, num_concurrent_enc_frame_partition: u32, reserved3: u32, ) -> __BindgenBitfieldUnit<[u8; 20]>