_VAEncMiscParameterMaxSliceSize

Struct _VAEncMiscParameterMaxSliceSize 

#[repr(C)]
pub struct _VAEncMiscParameterMaxSliceSize { pub max_slice_size: u32, pub va_reserved: [u32; 4], }
Allow a maximum slice size to be specified (in bits). The encoder will attempt to make sure that individual slices do not exceed this size Or to signal applicate if the slice size exceed this size, see “status” of VACodedBufferSegment

Fields

max_slice_size: u32va_reserved: [u32; 4]

\brief Reserved bytes for future use, must be zero