_VAEncMiscParameterQuantization

Struct _VAEncMiscParameterQuantization 

#[repr(C)]
pub struct _VAEncMiscParameterQuantization { pub quantization_flags: _VAEncMiscParameterQuantization__bindgen_ty_1, pub va_reserved: u32, }
\brief Quantization settings for encoding.

Some encoders support special types of quantization such as trellis, and this structure can be used by the app to control these special types of quantization by the encoder.

Fields

quantization_flags: _VAEncMiscParameterQuantization__bindgen_ty_1va_reserved: u32