_VAEncSegMapBufferAV1

Struct _VAEncSegMapBufferAV1 

#[repr(C)]
pub struct _VAEncSegMapBufferAV1 { pub segmentMapDataSize: u32, pub pSegmentMap: *mut u8, }
\brief Segment map data buffer.

This buffer is optional depending on the value of av1_segments.segmentation_enabled. If av1_segments.segmentation_enabled in the picture parameters equals 1, and RateControlMethod is not CQP and this surface is not provided by App, the encoder will determine the per block segmentation map. In this case, App should not provide the segmentation parameter data structure in frame header as well. If av1_segments.segmentation_enabled equals 1 and the segmentation map buffer is provided, app should embed the segmentation info in frame header, populate the VAEncSegParamAV1 structure with #VAEncMacroblockMapBufferType and the driver as well as the underline encoder should honor what is given by the app.

Fields

segmentMapDataSize: u32

\brief Segment map data size.

pSegmentMap: *mut u8

\brief Segment map. Size of this map is indicated by \ref segmentMapDataSize and each element in this map contains the segment id of a particular block. The element is indexed by raster scan order. The value of each entry should be in the range [0..7], inclusive.