_VAEncSequenceParameterBufferAV1

Struct _VAEncSequenceParameterBufferAV1 

#[repr(C)]
pub struct _VAEncSequenceParameterBufferAV1 { pub seq_profile: u8, pub seq_level_idx: u8, pub seq_tier: u8, pub hierarchical_flag: u8, pub intra_period: u32, pub ip_period: u32, pub bits_per_second: u32, pub seq_fields: _VAEncSequenceParameterBufferAV1__bindgen_ty_1, pub order_hint_bits_minus_1: u8, pub va_reserved: [u32; 16], }
\brief AV1 Encoding Sequence Parameter Buffer Structure.

This structure conveys sequence level parameters.

Fields

seq_profile: u8

\brief AV1 profile setting. value range [0..2].

seq_level_idx: u8

\brief Level Setting of current operation point. value range [0..23].

seq_tier: u8

\brief Tier Setting of current operation point. value range [0..1].

hierarchical_flag: u8

\brief Indicates whether or not the encoding is in dyadic hierarchical GOP structure. value range [0..1].

intra_period: u32

\brief Period between intra_only frames.

ip_period: u32

\brief Period between I/P frames. For hierarchical structure, this is the anchor frame distance.

bits_per_second: u32

\brief Initial bitrate set for this sequence in CBR or VBR modes.

This field represents the initial bitrate value for CBR mode or initial max bitrate value for VBR mode in this sequence. i.e. if the encoder pipeline was created with a #VAConfigAttribRateControl attribute set to either \ref VA_RC_CBR or \ref VA_RC_VBR.

The bitrate can be modified later on through #VAEncMiscParameterRateControl buffers.

seq_fields: _VAEncSequenceParameterBufferAV1__bindgen_ty_1order_hint_bits_minus_1: u8

\brief Corresponds to AV1 syntax element of the same name. value range [0..7].

va_reserved: [u32; 16]

\brief Reserved bytes for future use, must be zero