_VAEncSequenceParameterBufferMPEG2

Struct _VAEncSequenceParameterBufferMPEG2 

#[repr(C)]
pub struct _VAEncSequenceParameterBufferMPEG2 { pub intra_period: u32, pub ip_period: u32, pub picture_width: u16, pub picture_height: u16, pub bits_per_second: u32, pub frame_rate: f32, pub aspect_ratio_information: u16, pub vbv_buffer_size: u32, pub sequence_extension: _VAEncSequenceParameterBufferMPEG2__bindgen_ty_1, pub new_gop_header: u32, pub gop_header: _VAEncSequenceParameterBufferMPEG2__bindgen_ty_2, pub va_reserved: [u32; 4], }
\brief Sequence parameter for MPEG-2 encoding

This structure holds information for \c sequence_header() and sequence_extension().

If packed sequence headers mode is used, i.e. if the encoding pipeline was configured with the #VA_ENC_PACKED_HEADER_SEQUENCE flag, then the driver expects two more buffers to be provided to the same \c vaRenderPicture() as this buffer:

  • a #VAEncPackedHeaderParameterBuffer with type set to VAEncPackedHeaderType::VAEncPackedHeaderSequence ;
  • a #VAEncPackedHeaderDataBuffer which holds the actual packed header data.

Fields

intra_period: u32

\brief Period between I frames.

ip_period: u32

\brief Period between I/P frames.

picture_width: u16

\brief Picture width.

A 14bits unsigned inter, the lower 12bits is horizontal_size_value, and the upper 2bits is \c horizontal_size_extension

picture_height: u16

\brief Picture height.

A 14bits unsigned inter, the lower 12bits is vertical_size_value, and the upper 2bits is vertical_size_size_extension

bits_per_second: u32

\brief Initial bitrate set for this sequence in CBR or VBR modes.

This field represents the initial bitrate value for this sequence if CBR or VBR mode is used, i.e. if the encoder pipeline was created with a #VAConfigAttribRateControl attribute set to either \ref VA_RC_CBR or \ref VA_RC_VBR.

bits_per_second may be derived from bit_rate.

frame_rate: f32

\brief Frame rate

Derived from frame_rate_value, frame_rate_extension_n and frame_rate_extension_d

aspect_ratio_information: u16

\brief Same as the element in sequence_header()

vbv_buffer_size: u32

\brief Define the size of VBV

sequence_extension: _VAEncSequenceParameterBufferMPEG2__bindgen_ty_1new_gop_header: u32

\brief Flag to indicate the following GOP header are being updated

gop_header: _VAEncSequenceParameterBufferMPEG2__bindgen_ty_2va_reserved: [u32; 4]

\brief Reserved bytes for future use, must be zero