#[repr(C)]pub struct _VAEncTileGroupBufferAV1 {
pub tg_start: u8,
pub tg_end: u8,
pub va_reserved: [u32; 4],
}Expand description
\brief Tile Group Buffer.
Fields
tg_start: u8\brief Tile group start location. The position of the first tile in current tile group in raster scan order across the frame. value range [0..127].
tg_end: u8\brief Tile group end location. The position of the last tile in current tile group in raster scan order across the frame. value range [0..127].
va_reserved: [u32; 4]\brief Reserved bytes for future use, must be zero.