_VAProbabilityDataBufferVP8

Struct _VAProbabilityDataBufferVP8 

#[repr(C)]
pub struct _VAProbabilityDataBufferVP8 { pub dct_coeff_probs: [[[[u8; 11]; 3]; 8]; 4], pub va_reserved: [u32; 4], }
\brief VP8 Coefficient Probability Data Buffer Structure

Contains the contents of the token probability table, which may be incrementally modified in the frame header. There are four dimensions to the token probability array. The outermost dimension is indexed by the type of plane being decoded; the next dimension is selected by the position of the coefficient being decoded; the third dimension, * roughly speaking, measures the “local complexity” or extent to which nearby coefficients are non-zero; the fourth, and final, dimension of the token probability array is indexed by the position in the token tree structure, as are all tree probability arrays. This structure is sent once per frame.

Fields

dct_coeff_probs: [[[[u8; 11]; 3]; 8]; 4]va_reserved: [u32; 4]

\brief Reserved bytes for future use, must be zero