#[repr(C)]pub struct _VAProcFilterCap {
pub range: VAProcFilterValueRange,
pub va_reserved: [u32; 4],
}Expand description
\brief Default filter cap specification (single range value).
Unless there is a filter-specific cap structure, #VAProcFilterCap is the default type to use for output caps from vaQueryVideoProcFilterCaps().
Fields
range: VAProcFilterValueRange\brief Range of supported values for the filter.
va_reserved: [u32; 4]\brief Reserved bytes for future use, must be zero