#[repr(C)]pub struct _VAProcFilterCap3DLUT {
pub lut_size: u16,
pub lut_stride: [u16; 3],
pub bit_depth: u16,
pub num_channel: u16,
pub channel_mapping: u32,
pub va_reserved: [u32; 16],
}Expand description
\brief Capabilities specification for the 3DLUT filter.
Fields
lut_size: u16\brief lut_size is the number of valid points on every dimension of the three dimensional look up table.
lut_stride: [u16; 3]\brief lut_stride are the number of points on every dimension of the three dimensional look up table. lut3d[lut_stride[0]][lut_stride[1]][lut_stride[2]]
bit_depth: u16\brief bit_depth is the number of bits for every channel R, G or B (or Y, U, V)
num_channel: u16\brief num_channel is the number of channels
channel_mapping: u32\brief channel_mapping defines the mapping of channels, could be some combination of VA_3DLUT_CHANNEL_XXX
va_reserved: [u32; 16]\brief Reserved bytes for future use, must be zero