#[repr(C)]pub struct _VAProcFilterCapHighDynamicRange {
pub metadata_type: VAProcHighDynamicRangeMetadataType,
pub caps_flag: u16,
pub va_reserved: [u16; 16],
}Expand description
\brief Capabilities specification for the High Dynamic Range filter.
Fields
metadata_type: VAProcHighDynamicRangeMetadataType\brief high dynamic range type.
caps_flag: u16\brief flag for high dynamic range tone mapping
The flag is the combination of VA_TONE_MAPPING_XXX_TO_XXX. It could be VA_TONE_MAPPING_HDR_TO_HDR | VA_TONE_MAPPING_HDR_TO_SDR. SDR content to SDR display is always supported by default since it is legacy path.
va_reserved: [u16; 16]\brief Reserved bytes for future use, must be zero