#[repr(C)]pub struct _VAProcFilterParameterBufferBase {
pub type_: VAProcFilterType,
}Expand description
\brief Filter parameter buffer base.
This is a helper structure used by driver implementations only. Users are not supposed to allocate filter parameter buffers of this type.
Fields
type_: VAProcFilterType\brief Filter type.