#[repr(C)]pub struct _VAProcFilterParameterBufferHDRToneMapping {
pub type_: VAProcFilterType,
pub data: VAHdrMetaData,
pub va_reserved: [u32; 16],
}Expand description
\brief High Dynamic Range(HDR) Tone Mapping filter parametrization.
Fields
type_: VAProcFilterType\brief Filter type. Shall be set to #VAProcFilterHighDynamicRangeToneMapping.
data: VAHdrMetaData\brief High Dynamic Range metadata, could be HDR10 etc.
This metadata is mainly for the input surface. Given that dynamic metadata is changing on frame-by-frame or scene-by-scene basis for HDR10 plus, differentiate the metadata for the input and output.
va_reserved: [u32; 16]\brief Reserved bytes for future use, must be zero