#[repr(C)]pub struct _VAProcFilterValueRange {
pub min_value: f32,
pub max_value: f32,
pub default_value: f32,
pub step: f32,
pub va_reserved: [u32; 4],
}Expand description
\brief Specification of values supported by the filter.
Fields
min_value: f32\brief Minimum value supported, inclusive.
max_value: f32\brief Maximum value supported, inclusive.
default_value: f32\brief Default value.
step: f32\brief Step value that alters the filter behaviour in a sensible way.
va_reserved: [u32; 4]\brief Reserved bytes for future use, must be zero