_VAProcPipelineCaps

Struct _VAProcPipelineCaps 

#[repr(C)]
pub struct _VAProcPipelineCaps {
Show 25 fields pub pipeline_flags: u32, pub filter_flags: u32, pub num_forward_references: u32, pub num_backward_references: u32, pub input_color_standards: *mut VAProcColorStandardType, pub num_input_color_standards: u32, pub output_color_standards: *mut VAProcColorStandardType, pub num_output_color_standards: u32, pub rotation_flags: u32, pub blend_flags: u32, pub mirror_flags: u32, pub num_additional_outputs: u32, pub num_input_pixel_formats: u32, pub input_pixel_format: *mut u32, pub num_output_pixel_formats: u32, pub output_pixel_format: *mut u32, pub max_input_width: u32, pub max_input_height: u32, pub min_input_width: u32, pub min_input_height: u32, pub max_output_width: u32, pub max_output_height: u32, pub min_output_width: u32, pub min_output_height: u32, pub va_reserved: [u32; 14],
}
\brief Video processing pipeline capabilities.

Fields

pipeline_flags: u32

\brief Pipeline flags. See VAProcPipelineParameterBuffer::pipeline_flags.

filter_flags: u32

\brief Extra filter flags. See VAProcPipelineParameterBuffer::filter_flags.

num_forward_references: u32

\brief Number of forward reference frames that are needed.

num_backward_references: u32

\brief Number of backward reference frames that are needed.

input_color_standards: *mut VAProcColorStandardType

\brief List of color standards supported on input.

num_input_color_standards: u32

\brief Number of elements in \ref input_color_standards array.

output_color_standards: *mut VAProcColorStandardType

\brief List of color standards supported on output.

num_output_color_standards: u32

\brief Number of elements in \ref output_color_standards array.

rotation_flags: u32

\brief Rotation flags.

For each rotation angle supported by the underlying hardware, the corresponding bit is set in \ref rotation_flags. See “Rotation angles” for a description of rotation angles.

A value of 0 means the underlying hardware does not support any rotation. Otherwise, a check for a specific rotation angle can be performed as follows:

\code VAProcPipelineCaps pipeline_caps; … vaQueryVideoProcPipelineCaps(va_dpy, vpp_ctx, filter_bufs, num_filter_bufs, &pipeline_caps ); … if (pipeline_caps.rotation_flags & (1 << VA_ROTATION_xxx)) { // Clockwise rotation by xxx degrees is supported … } \endcode

blend_flags: u32

\brief Blend flags. See “Video blending flags”.

mirror_flags: u32

\brief Mirroring flags.

For each mirroring direction supported by the underlying hardware, the corresponding bit is set in \ref mirror_flags. See “Mirroring directions” for a description of mirroring directions.

num_additional_outputs: u32

\brief Number of additional output surfaces supported by the pipeline

num_input_pixel_formats: u32

\brief Number of elements in \ref input_pixel_format array.

input_pixel_format: *mut u32

\brief List of input pixel formats in fourcc.

num_output_pixel_formats: u32

\brief Number of elements in \ref output_pixel_format array.

output_pixel_format: *mut u32

\brief List of output pixel formats in fourcc.

max_input_width: u32

\brief Max supported input width in pixels.

max_input_height: u32

\brief Max supported input height in pixels.

min_input_width: u32

\brief Min supported input width in pixels.

min_input_height: u32

\brief Min supported input height in pixels.

max_output_width: u32

\brief Max supported output width in pixels.

max_output_height: u32

\brief Max supported output height in pixels.

min_output_width: u32

\brief Min supported output width in pixels.

min_output_height: u32

\brief Min supported output height in pixels.

va_reserved: [u32; 14]