ExternalBufferDescriptor

Trait ExternalBufferDescriptor 

pub trait ExternalBufferDescriptor {
    type DescriptorAttribute: SurfaceExternalDescriptor;

    const MEMORY_TYPE: MemoryType;

    // Required method
    fn va_surface_attribute(&mut self) -> Self::DescriptorAttribute;
}
Trait allowing to import an external memory source to use with a surface by setting the VASurfaceAttribMemoryType and VASurfaceAttribExternalBuffers attributes.

Required Associated Constants

const MEMORY_TYPE: MemoryType

Memory type to set for VASurfaceAttribMemoryType.

Required Associated Types

type DescriptorAttribute: SurfaceExternalDescriptor

Type of the descriptor to be set with VASurfaceAttribExternalBuffers.

Required Methods

fn va_surface_attribute(&mut self) -> Self::DescriptorAttribute

Returns the Self::DescriptorAttribute instance allowing this memory to be imported into VAAPI.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors