VABlendState

Type Alias VABlendState 

pub type VABlendState = _VABlendState;
\brief Video blending state definition.

Aliased Type

#[repr(C)]
pub struct VABlendState { pub flags: u32, pub global_alpha: f32, pub min_luma: f32, pub max_luma: f32, }

Fields

flags: u32

\brief Video blending flags.

global_alpha: f32

\brief Global alpha value.

Valid if \ref flags has VA_BLEND_GLOBAL_ALPHA. Valid range is 0.0 to 1.0 inclusive.

min_luma: f32

\brief Minimum luma value.

Valid if \ref flags has VA_BLEND_LUMA_KEY. Valid range is 0.0 to 1.0 inclusive. \ref min_luma shall be set to a sensible value lower than \ref max_luma.

max_luma: f32

\brief Maximum luma value.

Valid if \ref flags has VA_BLEND_LUMA_KEY. Valid range is 0.0 to 1.0 inclusive. \ref max_luma shall be set to a sensible value larger than \ref min_luma.