VABufferID

Type Alias VABufferID 

pub type VABufferID = VAGenericID;
Buffers Buffers are used to pass various types of data from the client to the server. The server maintains a data store for each buffer created, and the client idenfies a buffer through a unique buffer id assigned by the server.