VACodedBufferSegment

Type Alias VACodedBufferSegment 

pub type VACodedBufferSegment = _VACodedBufferSegment;
\brief Coded buffer segment.

#VACodedBufferSegment is an element of a linked list describing some information on the coded buffer. The coded buffer segment could contain either a single NAL unit, or more than one NAL unit. It is recommended (but not required) to return a single NAL unit in a coded buffer segment, and the implementation should set the VA_CODED_BUF_STATUS_SINGLE_NALU status flag if that is the case.

Aliased Type

#[repr(C)]
pub struct VACodedBufferSegment { pub size: u32, pub bit_offset: u32, pub status: u32, pub reserved: u32, pub buf: *mut c_void, pub next: *mut c_void, pub va_reserved: [u32; 4], }

Fields

size: u32

\brief Size of the data buffer in this segment (in bytes).

bit_offset: u32

\brief Bit offset into the data buffer where the video data starts.

status: u32

\brief Status set by the driver. See \c VA_CODED_BUF_STATUS_*.

reserved: u32

\brief Reserved for future use.

buf: *mut c_void

\brief Pointer to the start of the data buffer.

next: *mut c_void

\brief Pointer to the next #VACodedBufferSegment element, or \c NULL if there is none.

va_reserved: [u32; 4]

\brief Reserved bytes for future use, must be zero