VACodedBufferVP9Status

Type Alias VACodedBufferVP9Status 

pub type VACodedBufferVP9Status = _VACodedBufferVP9Status;
\brief VP9 Encoding Status Data Buffer Structure

This structure is used to convey status data from encoder to application. Driver allocates VACodedBufferVP9Status as a private data buffer. Driver encapsulates the status buffer with a VACodedBufferSegment, and sets VACodedBufferSegment.status to be VA_CODED_BUF_STATUS_CODEC_SPECIFIC. And driver associates status data segment to the bit stream buffer segment by setting VACodedBufferSegment.next of coded_buf (bit stream) to the private buffer segment of status data. Application accesses it by calling VAMapBuffer() with VAEncCodedBufferType.

Aliased Type

#[repr(C)]
pub struct VACodedBufferVP9Status { pub base_qp_index: u16, pub loop_filter_level: u8, pub long_term_indication: u8, pub next_frame_width: u16, pub next_frame_height: u16, pub va_reserved: [u32; 4], }

Fields

base_qp_index: u16

Final quantization index used (yac), determined by BRC. Application is providing quantization index deltas ydc(0), y2dc(1), y2ac(2), uvdc(3), uvac(4) that are applied to all segments and segmentation qi deltas, they will not be changed by BRC.

loop_filter_level: u8

Final loopfilter levels for the frame, if segmentation is disabled only index 0 is used. If loop_filter_level is 0, it indicates loop filter is disabled.

long_term_indication: u8

Long term reference frame indication from BRC. BRC recommends the current frame that is being queried is a good candidate for a long term reference.

next_frame_width: u16next_frame_height: u16va_reserved: [u32; 4]

\brief Reserved bytes for future use, must be zero