VAConfigAttrib

Type Alias VAConfigAttrib 

pub type VAConfigAttrib = _VAConfigAttrib;
Configuration attributes If there is more than one value for an attribute, a default value will be assigned to the attribute if the client does not specify the attribute when creating a configuration

Aliased Type

#[repr(C)]
pub struct VAConfigAttrib { pub type_: u32, pub value: u32, }

Fields

type_: u32value: u32