VAConfigAttribValEncAV1

Type Alias VAConfigAttribValEncAV1 

pub type VAConfigAttribValEncAV1 = _VAConfigAttribValEncAV1;
\brief Attribute value for VAConfigAttribEncAV1.

This attribute decribes the supported features of an AV1 encoder configuration.

All of the field values in this attribute are VA_FEATURE_* values, indicating support for the corresponding feature.

Aliased Type

#[repr(C)]
pub union VAConfigAttribValEncAV1 { pub bits: _VAConfigAttribValEncAV1__bindgen_ty_1, pub value: u32, }

Fields

bits: _VAConfigAttribValEncAV1__bindgen_ty_1value: u32