VADisplay

Type Alias VADisplay 

pub type VADisplay = *mut c_void;
Overview

The VA API is intended to provide an interface between a video decode/encode/processing application (client) and a hardware accelerator (server), to off-load video decode/encode/processing operations from the host to the hardware accelerator at various entry-points.

The basic operation steps are:

  • Negotiate a mutually acceptable configuration with the server to lock down profile, entrypoints, and other attributes that will not change on a frame-by-frame basis.
  • Create a video decode, encode or processing context which represents a “virtualized” hardware device
  • Get and fill the render buffers with the corresponding data (depending on profiles and entrypoints)
  • Pass the render buffers to the server to handle the current frame

Initialization & Configuration Management

  • Find out supported profiles
  • Find out entrypoints for a given profile
  • Find out configuration attributes for a given profile/entrypoint pair
  • Create a configuration for use by the application