VAEncFEIMBCodeH264

Type Alias VAEncFEIMBCodeH264 

pub type VAEncFEIMBCodeH264 = _VAEncFEIMBCodeH264;
\brief VAEncFEIMBCodeH264 defines the data structure for VAEncFEIMBCodeBufferType per 16x16 MB block. it is output buffer of ENC and ENC_PAK modes, it’s also input buffer of PAK mode. The 16x16 block is in raster scan order. Buffer size shall not be less than the number of 16x16 blocks multiplied by sizeof(VAEncFEIMBCodeH264). Note that, when separate ENC and PAK is enabled, the exact layout of this buffer is needed for PAK input. App can reuse this buffer, or copy to a different buffer as PAK input, reserved elements must not be modified when used as PAK input.

Aliased Type

#[repr(C)]
pub struct VAEncFEIMBCodeH264 { pub reserved0: [u32; 3], pub _bitfield_align_1: [u32; 0], pub _bitfield_1: __BindgenBitfieldUnit<[u8; 16]>, pub mb_mode: _VAEncFEIMBCodeH264__bindgen_ty_1, pub _bitfield_align_2: [u16; 0], pub _bitfield_2: __BindgenBitfieldUnit<[u8; 4]>, pub reserved9: [u32; 4], pub reserved10: u32, }

Fields

reserved0: [u32; 3]_bitfield_align_1: [u32; 0]_bitfield_1: __BindgenBitfieldUnit<[u8; 16]>mb_mode: _VAEncFEIMBCodeH264__bindgen_ty_1_bitfield_align_2: [u16; 0]_bitfield_2: __BindgenBitfieldUnit<[u8; 4]>reserved9: [u32; 4]reserved10: u32