VAEncFEIMVPredictorH264

Type Alias VAEncFEIMVPredictorH264 

pub type VAEncFEIMVPredictorH264 = _VAEncFEIMVPredictorH264;
\brief Application can use this definition as reference to allocate the buffer based on MaxNumPredictor returned from attribute VAConfigAttribFEIMVPredictors query.

Aliased Type

#[repr(C)]
pub struct VAEncFEIMVPredictorH264 { pub ref_idx: [_VAEncFEIMVPredictorH264__bindgen_ty_1; 4], pub reserved: u32, pub mv: [_VAMotionVector; 4], }

Fields

ref_idx: [_VAEncFEIMVPredictorH264__bindgen_ty_1; 4]reserved: u32mv: [_VAMotionVector; 4]

\brief MV. MaxNumPredictor must be the returned value from attribute VAConfigAttribFEIMVPredictors query. Even application doesn’t use the maximum predictors, the VAFEIMVPredictorH264 structure size has to be defined as maximum so each MB can be at a fixed location. Note that 0x8000 must be used for correspondent intra block.