pub type VAEncMiscParameterBufferROI = _VAEncMiscParameterBufferROI;Aliased Type
#[repr(C)]pub struct VAEncMiscParameterBufferROI {
pub num_roi: u32,
pub max_delta_qp: i8,
pub min_delta_qp: i8,
pub roi: *mut _VAEncROI,
pub roi_flags: _VAEncMiscParameterBufferROI__bindgen_ty_1,
pub va_reserved: [u32; 4],
}Fields
num_roi: u32\brief Number of ROIs being sent.
max_delta_qp: i8\brief Valid when VAConfigAttribRateControl != VA_RC_CQP, then the encoder’s rate control will determine actual delta QPs. Specifies the max/min allowed delta QPs.
min_delta_qp: i8roi: *mut _VAEncROI\brief Pointer to a VAEncROI array with num_roi elements. It is relative to frame coordinates for the frame case and to field coordinates for the field case.
roi_flags: _VAEncMiscParameterBufferROI__bindgen_ty_1va_reserved: [u32; 4]\brief Reserved bytes for future use, must be zero