VAEncMiscParameterFEIFrameControlHEVC

Type Alias VAEncMiscParameterFEIFrameControlHEVC 

pub type VAEncMiscParameterFEIFrameControlHEVC = _VAEncMiscParameterFEIFrameControlHEVC;
\brief FEI frame level control buffer for HEVC

Aliased Type

#[repr(C)]
pub struct VAEncMiscParameterFEIFrameControlHEVC {
Show 13 fields pub function: u32, pub ctb_ctrl: u32, pub ctb_cmd: u32, pub cu_record: u32, pub distortion: u32, pub qp: u32, pub mv_predictor: u32, pub _bitfield_align_1: [u32; 0], pub _bitfield_1: __BindgenBitfieldUnit<[u8; 20]>, pub max_frame_size: u32, pub num_passes: u32, pub delta_qp: *mut u8, pub reserved4: [u32; 2],
}

Fields

function: u32ctb_ctrl: u32

\brief CTB control input buffer. It is valid only when per_ctb_input is set to 1. The data in this buffer correspond to the input source. CTB is in raster scan order, each CTB control data structure is defined by VAEncFEICTBControlHEVC. Buffer size shall not be less than the number of CTBs multiplied by sizeof(VAEncFEICTBControlHEVC).

ctb_cmd: u32

\brief CTB cmd per CTB data output of ENC it is reserved for CTB level information it should include CU split information and other CTB datas . Each CTB block has one CTB cmd data.

cu_record: u32

\brief CU record data output of ENC it is reserved for CU level information it should include CU detail data. include mode,MV, reference etc. Each CTB block has one CU record data.

distortion: u32

\brief distortion output of ENC or ENC_PAK. Each CTB has one distortion data with VAEncFEIDistortionHevc Buffer size shall not be less than the number of CTBs multiplied by sizeof(VAEncFEIDistortionHevc).

qp: u32

\brief Qp input buffer. It is valid only when per_block_qp is set to 1. The data in this buffer correspond to the input source. One Qp per block block is in raster scan order, each Qp is a signed char (8-bit) value.

mv_predictor: u32

\brief MV predictor. It is valid only when mv_predictor_input is set to non-zero. Each CTB block has one or more pair of motion vectors and the corresponding reference indexes as defined by VAEncFEIMVPredictorHEVC. 32x32 block is in raster scan order. Buffer size shall not be less than the number of 16x16 blocks multiplied by sizeof(VAEncFEIMVPredictorHEVC).

_bitfield_align_1: [u32; 0]_bitfield_1: __BindgenBitfieldUnit<[u8; 20]>max_frame_size: u32

\brief max frame size control with multi passes QP setting

num_passes: u32

\brief number of passes, every pass has different QP

delta_qp: *mut u8

\brief delta QP list for every pass

reserved4: [u32; 2]