VAEncMiscParameterTemporalLayerStructure

Type Alias VAEncMiscParameterTemporalLayerStructure 

pub type VAEncMiscParameterTemporalLayerStructure = _VAEncMiscParameterTemporalLayerStructure;
\brief Temporal layer Structure

Aliased Type

#[repr(C)]
pub struct VAEncMiscParameterTemporalLayerStructure { pub number_of_layers: u32, pub periodicity: u32, pub layer_id: [u32; 32], pub va_reserved: [u32; 4], }

Fields

number_of_layers: u32

\brief The number of temporal layers

periodicity: u32

\brief The length of the array defining frame layer membership. Should be 1-32

layer_id: [u32; 32]

\brief The array indicating the layer id for each frame

The layer id for the first frame in a coded sequence is always 0, so layer_id[] specifies the layer ids for frames starting from the 2nd frame.

va_reserved: [u32; 4]

\brief Reserved bytes for future use, must be zero