VAEncPictureParameterBufferMPEG2

Type Alias VAEncPictureParameterBufferMPEG2 

pub type VAEncPictureParameterBufferMPEG2 = _VAEncPictureParameterBufferMPEG2;
\brief Picture parameter for MPEG-2 encoding

This structure holds information for picture_header() and picture_coding_extension()

If packed picture headers mode is used, i.e. if the encoding pipeline was configured with the #VA_ENC_PACKED_HEADER_PICTURE flag, then the driver expects two more buffers to be provided to the same \c vaRenderPicture() as this buffer:

  • a #VAEncPackedHeaderParameterBuffer with type set to VAEncPackedHeaderType::VAEncPackedHeaderPicture ;
  • a #VAEncPackedHeaderDataBuffer which holds the actual packed header data.

Aliased Type

#[repr(C)]
pub struct VAEncPictureParameterBufferMPEG2 { pub forward_reference_picture: u32, pub backward_reference_picture: u32, pub reconstructed_picture: u32, pub coded_buf: u32, pub last_picture: u8, pub picture_type: u32, pub temporal_reference: u32, pub vbv_delay: u32, pub f_code: [[u8; 2]; 2], pub picture_coding_extension: _VAEncPictureParameterBufferMPEG2__bindgen_ty_1, pub composite_display: _VAEncPictureParameterBufferMPEG2__bindgen_ty_2, pub va_reserved: [u32; 4], }

Fields

forward_reference_picture: u32

\brief Forward reference picture

backward_reference_picture: u32

\brief Backward reference picture

reconstructed_picture: u32

\brief Reconstructed(decoded) picture

coded_buf: u32

\brief Output encoded bitstream.

\ref coded_buf has type #VAEncCodedBufferType. It should be large enough to hold the compressed NAL slice and possibly SPS and PPS NAL units.

last_picture: u8

\brief Flag to indicate the picture is the last one or not.

This fields holds 0 if the picture to be encoded is not the last one in the stream. Otherwise, it is \ref MPEG2_LAST_PICTURE_EOSTREAM.

picture_type: u32

\brief Picture type

temporal_reference: u32

\brief Same as the element in picture_header()

vbv_delay: u32

\brief Same as the element in picture_header()

f_code: [[u8; 2]; 2]

\brief Same as the element in Picture coding extension

picture_coding_extension: _VAEncPictureParameterBufferMPEG2__bindgen_ty_1composite_display: _VAEncPictureParameterBufferMPEG2__bindgen_ty_2va_reserved: [u32; 4]

\brief Reserved bytes for future use, must be zero