VAEncSegParamAV1

Type Alias VAEncSegParamAV1 

pub type VAEncSegParamAV1 = _VAEncSegParamAV1;
\brief Segment parameters

Aliased Type

#[repr(C)]
pub struct VAEncSegParamAV1 { pub seg_flags: _VAEncSegParamAV1__bindgen_ty_1, pub segment_number: u8, pub feature_data: [[i16; 8]; 8], pub feature_mask: [u8; 8], pub va_reserved: [u32; 4], }

Fields

seg_flags: _VAEncSegParamAV1__bindgen_ty_1segment_number: u8

If segmentation_enabled equals 1, this parameter indicates the number of segments conveyed through VAAPI. In this case, if segment_number equals 0, it will force the driver to determine how many segments would be created as well as the segmentation map to be generated. Also the driver shall write the segmentation_params() syntax in the uncompressed header at \c bit_offset_segmentation (back-annotation). In application, the rest parameters in this structure should be all set to 0 and ignored by driver. And app should NOT send the “Segment map data buffer”. In packed uncompressed header bitstream, app should write syntax element segmentation_enabled as 0 and segmentation_params() should be only 1-bit-long. If segment_number > 0, and segmentation_update_map = 1, app should provide the “Segment map data buffer” and populate the rest of the current data structure. And that underline encoder would honor the segmentation parameters feature_data[0..segment_number-1][] and feature_mask[0..segment_number-1], etc. Value range [0..8].

feature_data: [[i16; 8]; 8]

\brief segment parameters. feature_data[][] is equivalent to variable FeatureData[][] in spec, which is after clip3() operation. Clip3(x, y, z) = (z<x)? x : ((z > y)? y : z); The limit is defined in Segmentation_Feature_Max[ SEG_LVL_MAX ] = { 255, MAX_LOOP_FILTER, MAX_LOOP_FILTER, MAX_LOOP_FILTER, MAX_LOOP_FILTER, 7, 0, 0 }

feature_mask: [u8; 8]

\brief Bit field to indicate each feature is enabled or not per segment_id. Each bit is the feature_id.

va_reserved: [u32; 4]

\brief Reserved bytes for future use, must be zero.