VAPictureParameterBufferHEVC

Type Alias VAPictureParameterBufferHEVC 

pub type VAPictureParameterBufferHEVC = _VAPictureParameterBufferHEVC;
\brief HEVC Decoding Picture Parameter Buffer Structure

This structure conveys picture level parameters and should be sent once per frame.

Aliased Type

#[repr(C)]
pub struct VAPictureParameterBufferHEVC {
Show 38 fields pub CurrPic: _VAPictureHEVC, pub ReferenceFrames: [_VAPictureHEVC; 15], pub pic_width_in_luma_samples: u16, pub pic_height_in_luma_samples: u16, pub pic_fields: _VAPictureParameterBufferHEVC__bindgen_ty_1, pub sps_max_dec_pic_buffering_minus1: u8, pub bit_depth_luma_minus8: u8, pub bit_depth_chroma_minus8: u8, pub pcm_sample_bit_depth_luma_minus1: u8, pub pcm_sample_bit_depth_chroma_minus1: u8, pub log2_min_luma_coding_block_size_minus3: u8, pub log2_diff_max_min_luma_coding_block_size: u8, pub log2_min_transform_block_size_minus2: u8, pub log2_diff_max_min_transform_block_size: u8, pub log2_min_pcm_luma_coding_block_size_minus3: u8, pub log2_diff_max_min_pcm_luma_coding_block_size: u8, pub max_transform_hierarchy_depth_intra: u8, pub max_transform_hierarchy_depth_inter: u8, pub init_qp_minus26: i8, pub diff_cu_qp_delta_depth: u8, pub pps_cb_qp_offset: i8, pub pps_cr_qp_offset: i8, pub log2_parallel_merge_level_minus2: u8, pub num_tile_columns_minus1: u8, pub num_tile_rows_minus1: u8, pub column_width_minus1: [u16; 19], pub row_height_minus1: [u16; 21], pub slice_parsing_fields: _VAPictureParameterBufferHEVC__bindgen_ty_2, pub log2_max_pic_order_cnt_lsb_minus4: u8, pub num_short_term_ref_pic_sets: u8, pub num_long_term_ref_pic_sps: u8, pub num_ref_idx_l0_default_active_minus1: u8, pub num_ref_idx_l1_default_active_minus1: u8, pub pps_beta_offset_div2: i8, pub pps_tc_offset_div2: i8, pub num_extra_slice_header_bits: u8, pub st_rps_bits: u32, pub va_reserved: [u32; 8],
}

Fields

CurrPic: _VAPictureHEVC

\brief buffer description of decoded current picture only VA_PICTURE_HEVC_FIELD_PIC and VA_PICTURE_HEVC_BOTTOM_FIELD of “flags” fields are meaningful.

ReferenceFrames: [_VAPictureHEVC; 15]

\brief buffer description of reference frames in DPB

pic_width_in_luma_samples: u16

\brief picture width, shall be integer multiple of minimum CB size.

pic_height_in_luma_samples: u16

\brief picture height, shall be integer multiple of minimum CB size.

pic_fields: _VAPictureParameterBufferHEVC__bindgen_ty_1sps_max_dec_pic_buffering_minus1: u8

following parameters have same syntax with those in HEVC spec / /* \brief DPB size for current temporal layer

bit_depth_luma_minus8: u8bit_depth_chroma_minus8: u8pcm_sample_bit_depth_luma_minus1: u8pcm_sample_bit_depth_chroma_minus1: u8log2_min_luma_coding_block_size_minus3: u8log2_diff_max_min_luma_coding_block_size: u8log2_min_transform_block_size_minus2: u8log2_diff_max_min_transform_block_size: u8log2_min_pcm_luma_coding_block_size_minus3: u8log2_diff_max_min_pcm_luma_coding_block_size: u8max_transform_hierarchy_depth_intra: u8max_transform_hierarchy_depth_inter: u8init_qp_minus26: i8diff_cu_qp_delta_depth: u8pps_cb_qp_offset: i8pps_cr_qp_offset: i8log2_parallel_merge_level_minus2: u8num_tile_columns_minus1: u8num_tile_rows_minus1: u8column_width_minus1: [u16; 19]

when uniform_spacing_flag equals 1, application should populate column_width_minus[], and row_height_minus1[] with approperiate values.

row_height_minus1: [u16; 21]slice_parsing_fields: _VAPictureParameterBufferHEVC__bindgen_ty_2log2_max_pic_order_cnt_lsb_minus4: u8

following parameters have same syntax with those in HEVC spec

num_short_term_ref_pic_sets: u8num_long_term_ref_pic_sps: u8num_ref_idx_l0_default_active_minus1: u8num_ref_idx_l1_default_active_minus1: u8pps_beta_offset_div2: i8pps_tc_offset_div2: i8num_extra_slice_header_bits: u8st_rps_bits: u32

\brief number of bits that structure short_term_ref_pic_set( num_short_term_ref_pic_sets ) takes in slice segment header when short_term_ref_pic_set_sps_flag equals 0. if short_term_ref_pic_set_sps_flag equals 1, the value should be 0. the bit count is calculated after emulation prevention bytes are removed from bit streams. This variable is used for accelorater to skip parsing the short_term_ref_pic_set( num_short_term_ref_pic_sets ) structure.

va_reserved: [u32; 8]

\brief Reserved bytes for future use, must be zero