VAProtectedSessionID

Type Alias VAProtectedSessionID 

pub type VAProtectedSessionID = VAGenericID;
ProtectedSessions and Contexts

According to #VAContextID, Context represents a “virtual” video decode, encode or video processing pipeline. Surfaces are render targets for a given context. The data in the surfaces are not accessible to the client except if derived image is supported and the internal data format of the surface is implementation specific. Application can create a video decode, encode or processing context which represents a “virtualized” hardware device.

Since Protected Session does not virtualize any HW device or build any pipeline but rather accessorize existing virtualized HW device or pipeline to operate in protected mode so we decided to create separate function. Beside this, a virtualized HW device or pipeline could own several protected sessions and operate in those protected modes without ever re-creating virtualization of HW device or re-building HW pipeline (an unique protected environment multiplexing capability in Intel HW).

The returned protected_session represents a notion of Host and TEE clients while representing protection status in GPU and Display.

Both contexts and protected sessions are identified by unique IDs and its implementation specific internals are kept opaque to the clients