VASegmentationStructAV1

Type Alias VASegmentationStructAV1 

pub type VASegmentationStructAV1 = _VASegmentationStructAV1;
\brief Segmentation Information

Aliased Type

#[repr(C)]
pub struct VASegmentationStructAV1 { pub segment_info_fields: _VASegmentationStructAV1__bindgen_ty_1, pub feature_data: [[i16; 8]; 8], pub feature_mask: [u8; 8], pub va_reserved: [u32; 4], }

Fields

segment_info_fields: _VASegmentationStructAV1__bindgen_ty_1feature_data: [[i16; 8]; 8]

\brief Segmentation parameters for current frame. feature_data[segment_id][feature_id] where segment_id has value range [0..7] indicating the segment id. and feature_id is defined as typedef enum { SEG_LVL_ALT_Q, // Use alternate Quantizer …. SEG_LVL_ALT_LF_Y_V, // Use alternate loop filter value on y plane vertical SEG_LVL_ALT_LF_Y_H, // Use alternate loop filter value on y plane horizontal SEG_LVL_ALT_LF_U, // Use alternate loop filter value on u plane SEG_LVL_ALT_LF_V, // Use alternate loop filter value on v plane SEG_LVL_REF_FRAME, // Optional Segment reference frame SEG_LVL_SKIP, // Optional Segment (0,0) + skip mode SEG_LVL_GLOBALMV, SEG_LVL_MAX } SEG_LVL_FEATURES; feature_data[][] is equivalent to variable FeatureData[][] in spec, which is after clip3() operation. Clip3(x, y, z) = (z < x)? x : ((z > y)? y : z); The limit is defined in Segmentation_Feature_Max[ SEG_LVL_MAX ] = { 255, MAX_LOOP_FILTER, MAX_LOOP_FILTER, MAX_LOOP_FILTER, MAX_LOOP_FILTER, 7, 0, 0 }

feature_mask: [u8; 8]

\brief indicates if a feature is enabled or not. Each bit field itself is the feature_id. Index is segment_id. feature_mask[segment_id] & (1 << feature_id) equal to 1 specify that the feature of feature_id for segment of segment_id is enabled, otherwise disabled.

va_reserved: [u32; 4]

\brief Reserved bytes for future use, must be zero