#[repr(C)]pub union VARefFrameCtrlAV1 {
pub fields: VARefFrameCtrlAV1__bindgen_ty_1,
pub value: u32,
}Expand description
\brief Reference frame control.
Suggest which frame to be used as reference along with preferred search order.
search_idx#: index into ref_frame_idx[] to indicate that frame will be included in the reference list if value in range [1..7]. Invalid when value is 0. The order of the search_idx# indicates the preferred search order.
Fields
fields: VARefFrameCtrlAV1__bindgen_ty_1value: u32Trait Implementations
Sourceimpl Clone for VARefFrameCtrlAV1
impl Clone for VARefFrameCtrlAV1
Sourcefn clone(&self) -> VARefFrameCtrlAV1
fn clone(&self) -> VARefFrameCtrlAV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for VARefFrameCtrlAV1