Constants
- VAAlf
Buffer Type - \brief VVC ALF data buffer
- VABit
Plane Buffer Type - VABuffer
Type Max - \brief VVC Slice Structure data buffer
- VAContext
Parameter Update Buffer Type - \brief adjust context parameters dynamically
- VADeblocking
Parameter Buffer Type - VADecode
Streamout Buffer Type - decode stream out buffer, intermedia data of decode, it may include MV, MB mode etc. it can be used to detect motion and analyze the frame contain
- VAEnc
Coded Buffer Type - VAEnc
Delta QpPer Block Buffer Type - \brief Encoding delta QP per block buffer
- VAEncFEICTB
CmdBuffer Type - \brief HEVC FEI CTB level cmd buffer it is CTB level information for future usage.
- VAEncFEICU
Record Buffer Type - \brief HEVC FEI CU level data buffer it’s CTB level information for future usage
- VAEncFEI
Distortion Buffer Type - \brief FEI specific buffer types
- VAEncFEIMB
Code Buffer Type - \brief FEI specific buffer types
- VAEncFEIMB
Control Buffer Type - \brief FEI specific buffer types
- VAEncFEIMV
Buffer Type - \brief FEI specific buffer types
- VAEncFEIMV
Predictor Buffer Type - \brief FEI specific buffer types
- VAEnc
Macroblock Disable Skip MapBuffer Type - Force MB’s to be non skip for encode.it’s per-mb control buffer, The width of the MB map Surface is (width of the Picture in MB unit) * 1 byte, multiple of 64 bytes. The height is (height of the picture in MB unit). The picture is either frame or non-interleaved top or bottom field. If the application provides this surface, it will override the “skipCheckDisable” setting in VAEncMiscParameterEncQuality.
- VAEnc
Macroblock MapBuffer Type - VAEnc
Macroblock Parameter Buffer Type - VAEnc
Misc Parameter Buffer Type - VAEnc
Packed Header Data Buffer Type - VAEnc
Packed Header Parameter Buffer Type - VAEnc
Picture Parameter Buffer Type - VAEncQP
Buffer Type - \brief Encoding QP buffer
- VAEnc
Sequence Parameter Buffer Type - VAEnc
Slice Parameter Buffer Type - VAEncryption
Parameter Buffer Type - \brief Encryption parameters buffer for protected content session.
- VAHuffman
Table Buffer Type - VAIQ
Matrix Buffer Type - VAImage
Buffer Type - VALmcs
Buffer Type - \brief VVC LMCS data buffer
- VAMacroblock
Parameter Buffer Type - VAPicture
Parameter Buffer Type - VAProbability
Buffer Type - VAProc
Filter Parameter Buffer Type - \brief Video filter parameter buffer.
- VAProc
Pipeline Parameter Buffer Type - \brief Video processing pipeline parameter buffer.
- VAProtected
Session Execute Buffer Type - \brief Protected session execution buffer type
- VAProtected
Slice Data Buffer Type - VAQMatrix
Buffer Type - VAResidual
Data Buffer Type - VASlice
Data Buffer Type - VASlice
Group MapBuffer Type - VASlice
Parameter Buffer Type - VASlice
Struct Buffer Type - \brief VVC Slice Structure data buffer
- VAStatsMV
Buffer Type - \brief Statistics output for VAEntrypointStats bottom field of interlaced case
- VAStatsMV
Predictor Buffer Type - \brief Statistics output for VAEntrypointStats bottom field of interlaced case
- VAStats
Statistics Bottom Field Buffer Type - \brief Statistics output for VAEntrypointStats bottom field of interlaced case
- VAStats
Statistics Buffer Type - \brief Statistics output for VAEntrypointStats progressive and top field of interlaced case
- VAStats
Statistics Parameter Buffer Type - \brief FEI specific buffer types
- VASub
PicBuffer Type - \brief VVC SubPic data buffer
- VASubsets
Parameter Buffer Type - \brief HEVC Decoding Subset Parameter buffer type
- VATile
Buffer Type - \brief VVC Tile Dimension data buffer