HrdParams

Struct HrdParams 

pub struct HrdParams {
    pub cpb_cnt_minus1: u8,
    pub bit_rate_scale: u8,
    pub cpb_size_scale: u8,
    pub bit_rate_value_minus1: [u32; 32],
    pub cpb_size_value_minus1: [u32; 32],
    pub cbr_flag: [bool; 32],
    pub initial_cpb_removal_delay_length_minus1: u8,
    pub cpb_removal_delay_length_minus1: u8,
    pub dpb_output_delay_length_minus1: u8,
    pub time_offset_length: u8,
}

Fields

cpb_cnt_minus1: u8

Plus 1 specifies the number of alternative CPB specifications in the bitstream. The value of cpb_cnt_minus1 shall be in the range of 0 to 31, inclusive

bit_rate_scale: u8

Together with bit_rate_value_minus1[ SchedSelIdx ] specifies the maximum input bit rate of the SchedSelIdx-th CPB.

cpb_size_scale: u8

Together with cpb_size_value_minus1[ SchedSelIdx ] specifies the CPB size of the SchedSelIdx-th CPB.

bit_rate_value_minus1: [u32; 32]

[ SchedSelIdx ] (together with bit_rate_scale) specifies the maximum input bit rate for the SchedSelIdx-th CPB.

cpb_size_value_minus1: [u32; 32]

[ SchedSelIdx ] is used together with cpb_size_scale to specify the SchedSelIdx-th CPB size.

cbr_flag: [bool; 32]

[ SchedSelIdx ] equal to 0 specifies that to decode this bitstream by the HRD using the SchedSelIdx-th CPB specification, the hypothetical stream delivery scheduler (HSS) operates in an intermittent bit rate mode. cbr_flag[ SchedSelIdx ] equal to 1 specifies that the HSS operates in a constant bit rate (CBR) mode

initial_cpb_removal_delay_length_minus1: u8

Specifies the length in bits of the initial_cpb_removal_delay[ SchedSelIdx ] and initial_cpb_removal_delay_offset[ SchedSelIdx ] syntax elements of the buffering period SEI message.

cpb_removal_delay_length_minus1: u8

Specifies the length in bits of the cpb_removal_delay syntax element.

dpb_output_delay_length_minus1: u8

Specifies the length in bits of the dpb_output_delay syntax element.

time_offset_length: u8

If greater than 0, specifies the length in bits of the time_offset syntax element. time_offset_length equal to 0 specifies that the time_offset syntax element is not present