pub unsafe extern "C" fn vaAssociateSubpicture(
dpy: VADisplay,
subpicture: VASubpictureID,
target_surfaces: *mut VASurfaceID,
num_surfaces: c_int,
src_x: i16,
src_y: i16,
src_width: u16,
src_height: u16,
dest_x: i16,
dest_y: i16,
dest_width: u16,
dest_height: u16,
flags: u32,
) -> VAStatusExpand description
vaAssociateSubpicture associates the subpicture with target_surfaces. It defines the region mapping between the subpicture and the target surfaces through source and destination rectangles (with the same width and height). Both will be displayed at the next call to vaPutSurface. Additional associations before the call to vaPutSurface simply overrides the association.