pub unsafe extern "C" fn vaCreateImage(
dpy: VADisplay,
format: *mut VAImageFormat,
width: c_int,
height: c_int,
image: *mut VAImage,
) -> VAStatusExpand description
Create a VAImage structure The width and height fields returned in the VAImage structure may get enlarged for some YUV formats. Upon return from this function, image->buf has been created and proper storage allocated by the library. The client can access the image through the Map/Unmap calls.