pub unsafe extern "C" fn vaCreateSurfaces(
dpy: VADisplay,
format: c_uint,
width: c_uint,
height: c_uint,
surfaces: *mut VASurfaceID,
num_surfaces: c_uint,
attrib_list: *mut VASurfaceAttrib,
num_attribs: c_uint,
) -> VAStatusExpand description
\brief Creates an array of surfaces
Creates an array of surfaces. The optional list of attributes shall be constructed based on what the underlying hardware could expose through vaQuerySurfaceAttributes().
@param[in] dpy the VA display @param[in] format the desired surface format. See \c VA_RT_FORMAT_* @param[in] width the surface width @param[in] height the surface height @param[out] surfaces the array of newly created surfaces @param[in] num_surfaces the number of surfaces to create @param[in] attrib_list the list of (optional) attributes, or \c NULL @param[in] num_attribs the number of attributes supplied in \c attrib_list, or zero