pub unsafe extern "C" fn vaEndPicture(
dpy: VADisplay,
context: VAContextID,
) -> VAStatusExpand description
Make the end of rendering for a picture. The server should start processing all pending operations for this surface. This call is non-blocking. The client can start another Begin/Render/End sequence on a different render target. if VAContextID used in this function previously successfully passed vaMFAddContext call, real processing will be started during vaMFSubmit