#[repr(C)]pub struct _VAEncFEIMVPredictorHEVC {
pub ref_idx: [_VAEncFEIMVPredictorHEVC__bindgen_ty_1; 4],
pub _bitfield_align_1: [u32; 0],
pub _bitfield_1: __BindgenBitfieldUnit<[u8; 4]>,
pub mv: [VAMotionVector; 4],
}Expand description
\brief Application can use this definition as reference to allocate the buffer based on MaxNumPredictor returned from attribute VAConfigAttribFEIMVPredictors query. this buffer allocation is always based on 16x16 block even block size is indicated as 32x32 or 64x64, and buffer layout is always in 32x32 block raster scan order even block size is 16x16 or 64x64. If 32x32 block size is set, only the data in the first 16x16 block (block 0) is used for 32x32 block. If 64x64 block size is set MV layout is still in 32x32 raster scan order, the same as 32x32 and the first 16x16 block within each 32x32 block needs to have intended MV data (four 32x32 blocks will have the same MV data in the correspondent first 16x16 block). Data structure for each 16x16 block is defined as below (same as AVC except BlockSize/Reserved bits).
Fields
ref_idx: [_VAEncFEIMVPredictorHEVC__bindgen_ty_1; 4]_bitfield_align_1: [u32; 0]_bitfield_1: __BindgenBitfieldUnit<[u8; 4]>mv: [VAMotionVector; 4]Implementations
Sourceimpl _VAEncFEIMVPredictorHEVC
impl _VAEncFEIMVPredictorHEVC
pub fn block_size(&self) -> u32
pub fn set_block_size(&mut self, val: u32)
pub fn reserved(&self) -> u32
pub fn set_reserved(&mut self, val: u32)
pub fn new_bitfield_1( block_size: u32, reserved: u32, ) -> __BindgenBitfieldUnit<[u8; 4]>