#[repr(C)]pub struct _VAEncMiscParameterFrameRate {
pub framerate: u32,
pub framerate_flags: _VAEncMiscParameterFrameRate__bindgen_ty_1,
pub va_reserved: [u32; 4],
}Expand description
Encode framerate parameters.
Sets the encode framerate used by the rate controller. This should be provided in all modes using a bitrate target (variable framerate is not supported).
Fields
framerate: u32Encode framerate.
The framerate is specified as a number of frames per second, as a fraction. The denominator of the fraction is given in the top half (the high two bytes) of the framerate field, and the numerator is given in the bottom half (the low two bytes).
That is: denominator = framerate >> 16 & 0xffff; numerator = framerate & 0xffff; fps = numerator / denominator;
For example, if framerate is set to (100 << 16 | 750), this is 750 / 100, hence 7.5fps.
If the denominator is zero (the high two bytes are both zero) then it takes the value one instead, so the framerate is just the integer in the low 2 bytes.
framerate_flags: _VAEncMiscParameterFrameRate__bindgen_ty_1va_reserved: [u32; 4]\brief Reserved bytes for future use, must be zero