#[repr(C)]pub struct _VAEncMiscParameterHRD {
pub initial_buffer_fullness: u32,
pub buffer_size: u32,
pub va_reserved: [u32; 4],
}Expand description
HRD / VBV buffering parameters for encoding.
This sets the HRD / VBV parameters which will be used by the rate controller for encoding. It should be specified in modes using a bitrate target when the buffering of the output stream needs to be constrained.
If not provided, the encoder may use arbitrary amounts of buffering.
Fields
initial_buffer_fullness: u32The initial fullness of the HRD coded picture buffer, in bits.
This sets how full the CPB is when encoding begins - that is, how much buffering will happen on the decoder side before the first frame. The CPB fullness will be reset to this value after any rate control reset (a change in parameters or an explicit reset).
For H.264, it should match the value of initial_cpb_removal_delay in buffering_period SEI messages.
buffer_size: u32The HRD coded picture buffer size, in bits.
For H.264, it should match the value of cpb_size_value_minus1 in the VUI parameters.
va_reserved: [u32; 4]\brief Reserved bytes for future use, must be zero