#[repr(C)]pub struct _VAEncMiscParameterQuantization {
pub quantization_flags: _VAEncMiscParameterQuantization__bindgen_ty_1,
pub va_reserved: u32,
}Expand description
\brief Quantization settings for encoding.
Some encoders support special types of quantization such as trellis, and this structure can be used by the app to control these special types of quantization by the encoder.
Fields
quantization_flags: _VAEncMiscParameterQuantization__bindgen_ty_1va_reserved: u32Trait Implementations
Sourceimpl Clone for _VAEncMiscParameterQuantization
impl Clone for _VAEncMiscParameterQuantization
Sourcefn clone(&self) -> _VAEncMiscParameterQuantization
fn clone(&self) -> _VAEncMiscParameterQuantization
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for _VAEncMiscParameterQuantization