#[repr(C)]pub struct _VAEncMiscParameterSkipFrame {
pub skip_frame_flag: u8,
pub num_skip_frames: u8,
pub size_skip_frames: u32,
pub va_reserved: [u32; 4],
}Expand description
\brief Encoding skip frame.
The application may choose to skip frames externally to the encoder (e.g. drop completely or code as all skip’s). For rate control purposes the encoder will need to know the size and number of skipped frames. Skip frame(s) indicated through this structure is applicable only to the current frame. It is allowed for the application to still send in packed headers for the driver to pack, although no frame will be encoded (e.g. for HW to encrypt the frame).
Fields
skip_frame_flag: u8\brief Indicates skip frames as below. 0: Encode as normal, no skip. 1: One or more frames were skipped prior to the current frame, encode the current frame as normal. 2: The current frame is to be skipped, do not encode it but pack/encrypt the packed header contents (all except VAEncPackedHeaderSlice) which could contain actual frame contents (e.g. pack the frame in VAEncPackedHeaderPicture).
num_skip_frames: u8\brief The number of frames skipped prior to the current frame. Valid when skip_frame_flag = 1.
size_skip_frames: u32\brief When skip_frame_flag = 1, the size of the skipped frames in bits. When skip_frame_flag = 2, the size of the current skipped frame that is to be packed/encrypted in bits.
va_reserved: [u32; 4]\brief Reserved bytes for future use, must be zero