#[repr(C)]pub struct _VAEncROI {
pub roi_rectangle: VARectangle,
pub roi_value: i8,
}Expand description
\brief Encoding region-of-interest (ROI).
The encoding ROI can be set through VAEncMiscParameterBufferROI, if the implementation supports ROI input. The ROI set through this structure is applicable only to the current frame or field, so must be sent every frame or field to be applied. The number of supported ROIs can be queried through the VAConfigAttribEncROI. The encoder will use the ROI information to adjust the QP values of the MB’s that fall within the ROIs.
Fields
roi_rectangle: VARectangle\brief Defines the ROI boundary in pixels, the driver will map it to appropriate codec coding units. It is relative to frame coordinates for the frame case and to field coordinates for the field case.
roi_value: i8\brief ROI value
\ref roi_value specifies ROI delta QP or ROI priority. – ROI delta QP is the value that will be added on top of the frame level QP. – ROI priority specifies the priority of a region, it can be positive (more important) or negative (less important) values and is compared with non-ROI region (taken as value 0), E.g. ROI region with \ref roi_value -3 is less important than the non-ROI region (\ref roi_value implied to be 0) which is less important than ROI region with roi_value +2. For overlapping regions, the roi_value that is first in the ROI array will have priority.
\ref roi_value always specifes ROI delta QP when VAConfigAttribRateControl == VA_RC_CQP, no matter the value of \c roi_value_is_qp_delta in #VAEncMiscParameterBufferROI.
\ref roi_value depends on \c roi_value_is_qp_delta in #VAEncMiscParameterBufferROI when VAConfigAttribRateControl != VA_RC_CQP. \ref roi_value specifies ROI_delta QP if \c roi_value_is_qp_delta in VAEncMiscParameterBufferROI is 1, otherwise \ref roi_value specifies ROI priority.