#[repr(C)]pub struct _VAEncSequenceParameterBufferHEVC {Show 32 fields
pub general_profile_idc: u8,
pub general_level_idc: u8,
pub general_tier_flag: u8,
pub intra_period: u32,
pub intra_idr_period: u32,
pub ip_period: u32,
pub bits_per_second: u32,
pub pic_width_in_luma_samples: u16,
pub pic_height_in_luma_samples: u16,
pub seq_fields: _VAEncSequenceParameterBufferHEVC__bindgen_ty_1,
pub log2_min_luma_coding_block_size_minus3: u8,
pub log2_diff_max_min_luma_coding_block_size: u8,
pub log2_min_transform_block_size_minus2: u8,
pub log2_diff_max_min_transform_block_size: u8,
pub max_transform_hierarchy_depth_inter: u8,
pub max_transform_hierarchy_depth_intra: u8,
pub pcm_sample_bit_depth_luma_minus1: u32,
pub pcm_sample_bit_depth_chroma_minus1: u32,
pub log2_min_pcm_luma_coding_block_size_minus3: u32,
pub log2_max_pcm_luma_coding_block_size_minus3: u32,
pub vui_parameters_present_flag: u8,
pub vui_fields: _VAEncSequenceParameterBufferHEVC__bindgen_ty_2,
pub aspect_ratio_idc: u8,
pub sar_width: u32,
pub sar_height: u32,
pub vui_num_units_in_tick: u32,
pub vui_time_scale: u32,
pub min_spatial_segmentation_idc: u16,
pub max_bytes_per_pic_denom: u8,
pub max_bits_per_min_cu_denom: u8,
pub scc_fields: _VAEncSequenceParameterBufferHEVC__bindgen_ty_3,
pub va_reserved: [u32; 7],
}Expand description
\brief Sequence parameter for HEVC encoding in main & main 10 profiles.
This structure holds information for \c seq_parameter_set_data() as defined by the HEVC specification.
If packed sequence headers mode is used, i.e. if the encoding pipeline was configured with the #VA_ENC_PACKED_HEADER_SEQUENCE flag, then the driver expects two more buffers to be provided to the same \c vaRenderPicture() as this buffer:
- a #VAEncPackedHeaderParameterBuffer with type set to VAEncPackedHeaderType::VAEncPackedHeaderSequence ;
- a #VAEncPackedHeaderDataBuffer which holds the actual packed header data.
If \c seq_scaling_matrix_present_flag is set to \c 1, then a #VAQMatrixBufferHEVC buffer shall also be provided within the same \c vaRenderPicture() call as this sequence parameter buffer.
Fields
general_profile_idc: u8\brief Same as the HEVC bitstream syntax element. value range [1..2].
general_level_idc: u8\brief Same as the HEVC bitstream syntax element. general_level_idc shall be set equal to a value of 30 times the level numbers allowed [1, 2, 2.1, 3, 3.1, 4, 4.1, 5, 5.1, 5.2, 6, 6.1, 6.2]
general_tier_flag: u8\brief Same as the HEVC bitstream syntax element. Only value 0 is allowed for level value below 4, exclusive.
intra_period: u32\brief Period between I frames.
intra_idr_period: u32\brief Period between IDR frames.
ip_period: u32\brief Period between I/P frames.
bits_per_second: u32\brief Initial bitrate set for this sequence in CBR or VBR modes.
This field represents the initial bitrate value for this sequence if CBR or VBR mode is used, i.e. if the encoder pipeline was created with a #VAConfigAttribRateControl attribute set to either \ref VA_RC_CBR or \ref VA_RC_VBR.
The bitrate can be modified later on through #VAEncMiscParameterRateControl buffers.
pic_width_in_luma_samples: u16\brief Picture width in pixel samples. Its value must be multiple of min CU size.
pic_height_in_luma_samples: u16\brief Picture height in pixel samples. Its value must be multiple of min CU size.
seq_fields: _VAEncSequenceParameterBufferHEVC__bindgen_ty_1log2_min_luma_coding_block_size_minus3: u8\brief Same as the HEVC bitstream syntax element. value range [0..3]
log2_diff_max_min_luma_coding_block_size: u8\brief Same as the HEVC bitstream syntax element.
log2_min_transform_block_size_minus2: u8\brief Same as the HEVC bitstream syntax element. value range [0..3]
log2_diff_max_min_transform_block_size: u8\brief Same as the HEVC bitstream syntax element.
max_transform_hierarchy_depth_inter: u8\brief Same as the HEVC bitstream syntax element. value range [2]
max_transform_hierarchy_depth_intra: u8\brief Same as the HEVC bitstream syntax element. value range [2]
pcm_sample_bit_depth_luma_minus1: u32\brief Same as the HEVC bitstream syntax element.
pcm_sample_bit_depth_chroma_minus1: u32\brief Same as the HEVC bitstream syntax element.
log2_min_pcm_luma_coding_block_size_minus3: u32\brief Same as the HEVC bitstream syntax element.
log2_max_pcm_luma_coding_block_size_minus3: u32\brief Derived from the HEVC bitstream syntax element. log2_min_pcm_luma_coding_block_size_minus3 + log2_diff_max_min_pcm_luma_coding_block_size
vui_parameters_present_flag: u8@name VUI parameters (optional) / /**@{/ /** \brief Same as the HEVC bitstream syntax element.
vui_fields: _VAEncSequenceParameterBufferHEVC__bindgen_ty_2aspect_ratio_idc: u8\brief Same as the HEVC bitstream syntax element.
sar_width: u32\brief Same as the HEVC bitstream syntax element.
sar_height: u32\brief Same as the HEVC bitstream syntax element.
vui_num_units_in_tick: u32\brief Same as the HEVC bitstream syntax element.
vui_time_scale: u32\brief Same as the HEVC bitstream syntax element.
min_spatial_segmentation_idc: u16\brief Same as the HEVC bitstream syntax element.
max_bytes_per_pic_denom: u8\brief Same as the HEVC bitstream syntax element.
max_bits_per_min_cu_denom: u8\brief Same as the HEVC bitstream syntax element.
scc_fields: _VAEncSequenceParameterBufferHEVC__bindgen_ty_3va_reserved: [u32; 7]\brief Reserved bytes for future use, must be zero