#[repr(C)]pub struct _VAPictureHEVC {
pub picture_id: VASurfaceID,
pub pic_order_cnt: i32,
pub flags: u32,
pub va_reserved: [u32; 4],
}Expand description
HEVC data structures / /** \brief Description of picture properties of those in DPB surfaces.
If only progressive scan is supported, each surface contains one whole frame picture. Otherwise, each surface contains two fields of whole picture. In this case, two entries of ReferenceFrames[] may share same picture_id value.
Fields
picture_id: VASurfaceID\brief reconstructed picture buffer surface index invalid when taking value VA_INVALID_SURFACE.
pic_order_cnt: i32\brief picture order count. in HEVC, POCs for top and bottom fields of same picture should take different values.
flags: u32va_reserved: [u32; 4]\brief Reserved bytes for future use, must be zero