pub type VAEncMBMapBufferVP8 = _VAEncMBMapBufferVP8;Expand description
\brief VP8 MB Segmentation ID Buffer
application provides buffer containing the initial segmentation id for each MB, in raster scan order. Rate control may reassign it. For an 640x480 video, the buffer has 1200 entries. the value of each entry should be in the range [0..3], inclusive. If segmentation is not enabled, application does not need to provide it.
Aliased Type
#[repr(C)]pub struct VAEncMBMapBufferVP8 {
pub num_mbs: u32,
pub mb_segment_id: *mut u8,
pub va_reserved: [u32; 4],
}Fields
num_mbs: u32number of MBs in the frame. It is also the number of entries of mb_segment_id[];
mb_segment_id: *mut u8per MB Segmentation ID Buffer
va_reserved: [u32; 4]\brief Reserved bytes for future use, must be zero