pub type VAEncMiscParameterEncQuality = _VAEncMiscParameterEncQuality;Expand description
per frame encoder quality controls, once set they will persist for all future frames till it is updated again.
Aliased Type
#[repr(C)]pub struct VAEncMiscParameterEncQuality {
pub __bindgen_anon_1: _VAEncMiscParameterEncQuality__bindgen_ty_1,
pub FTQSkipThresholdLUT: [u8; 52],
pub NonFTQSkipThresholdLUT: [u16; 52],
pub reserved: [u32; 16],
}Fields
__bindgen_anon_1: _VAEncMiscParameterEncQuality__bindgen_ty_1FTQSkipThresholdLUT: [u8; 52]Maps QP to skip thresholds when FTQ is enabled. Valid range is 0-255.
NonFTQSkipThresholdLUT: [u16; 52]Maps QP to skip thresholds when FTQ is disabled. Valid range is 0-65535.
reserved: [u32; 16]