pub type VAEncMiscParameterParallelRateControl = _VAEncMiscParameterParallelRateControl;Expand description
\brief Attribute value for VAConfigAttribEncParallelRateControl
Aliased Type
#[repr(C)]pub struct VAEncMiscParameterParallelRateControl {
pub num_layers: u32,
pub num_b_in_gop: *mut u32,
}Fields
num_layers: u32brief Number of layers
num_b_in_gop: *mut u32brief Number of B frames per layer per GOP.
it should be allocated by application, and the is num_layers. num_b_in_gop[0] is the number of regular B which refers to only I or P frames.